package {
	import com.transmote.flar.marker.FLARMarker;
	import com.transmote.flar.utils.geom.FLARPVGeomUtils;
	
	import flash.display.Loader;
	import flash.display.Sprite;
	import flash.events.Event;
	import flash.net.URLRequest;
	import flash.utils.Dictionary;
	
	import mx.core.BitmapAsset;
	
	import org.libspark.flartoolkit.core.param.FLARParam;
	import org.libspark.flartoolkit.support.pv3d.FLARCamera3D;
	import org.papervision3d.core.geom.renderables.Vertex3D;
	import org.papervision3d.lights.PointLight3D;
	import org.papervision3d.materials.BitmapFileMaterial;
	import org.papervision3d.materials.ColorMaterial;
	import org.papervision3d.materials.shadematerials.EnvMapMaterial;
	import org.papervision3d.materials.shadematerials.FlatShadeMaterial;
	import org.papervision3d.materials.special.LineMaterial;
	import org.papervision3d.materials.utils.MaterialsList;
	import org.papervision3d.objects.DisplayObject3D;
	import org.papervision3d.objects.parsers.DAE;
	import org.papervision3d.objects.primitives.Cylinder;
	import org.papervision3d.objects.primitives.Plane;
	import org.papervision3d.objects.primitives.Sphere;
	import org.papervision3d.render.LazyRenderEngine;
	import org.papervision3d.scenes.Scene3D;
	import org.papervision3d.view.Viewport3D;
	
	/**
	 * Augmented Reality Molecule Review Tool
	 * 
	 * Molecules Supported:
	 * 		C2H2
	 * 		C2H4
	 * 		C2H6
	 * 		CH3CHCH2
	 * 		CH3CONH2
	 * 		CH3NH2
	 * 		CH4
	 * 		CO2
	 * 		NH3
	 * 		OF2
	 * 		sp3, sp2, sp
	 * 
	 * Built with FLARManager	http://words.transmote.com/wp/flarmanager/
	 * 
	 *  
	 * @author	John Kunz
	 * @url		http://sponholtzproductions.com/
	 * @date	January 2010
	 */
	 
	public class Molecules_PV3D extends Sprite {
		private static const CUBE_SIZE:Number = 40;
		
		private var viewport3D:Viewport3D;
		private var camera3D:FLARCamera3D;
		private var scene3D:Scene3D;
		private var renderEngine:LazyRenderEngine;
		private var pointLight3D:PointLight3D;
		
		private var bMirrorDisplay:Boolean;
		private var markersByPatternId:Vector.<Vector.<FLARMarker>>;	// FLARMarkers, arranged by patternId
		private var containersByMarker:Dictionary;						// Containers, hashed by corresponding FLARMarker
		private var hydrogenMat:BitmapFileMaterial;
		private var carbonMat:BitmapFileMaterial;
		private var nitrogenMat:BitmapFileMaterial;
		private var oxygenMat:BitmapFileMaterial;
		private var fluorideMat:BitmapFileMaterial;
		private var bondMat:ColorMaterial;
		private var electronMat:ColorMaterial;
		private var redLobeEnv:EnvMapMaterial;
		private var blueLobeEnv:EnvMapMaterial;
		[Embed(source="../resources/texture/uffizi_probe2.png")]
        private var probeAsset:Class;
        [Embed(source="../resources/texture/uffizi_probeBlue.png")]
        private var blueProbeAsset:Class;
        private var redLobeMat:MaterialsList;
        private var blueLobeMat:MaterialsList;
        private var redLineMat:LineMaterial;
        private var yellowLineMat:LineMaterial;
        private var redArrow:MaterialsList;
        private var yellowArrow:MaterialsList;
        private var redArrowMat:ColorMaterial;
        private var yellowArrowMat:ColorMaterial;
        private var blueArrowMat:ColorMaterial;
        
		private var ch4_carbon01:Sphere;
		private var ch4_hydrogen01:Sphere;
		private var ch4_hydrogen02:Sphere;
		private var ch4_hydrogen03:Sphere;
		private var ch4_hydrogen04:Sphere;
		private var ch4_bond01:Cylinder;
		private var ch4_bond02:Cylinder;
		private var ch4_bond03:Cylinder;
		private var ch4_bond04:Cylinder;
		
		private var nh3_nitrogen01:Sphere;
		private var nh3_hydrogen01:Sphere;
		private var nh3_hydrogen02:Sphere;
		private var nh3_hydrogen03:Sphere;
		private var nh3_bond01:Cylinder;
		private var nh3_bond02:Cylinder;
		private var nh3_bond03:Cylinder;
		private var nh3_bond04:Cylinder;
		private var nh3_electron01a:Sphere;
		private var nh3_electron01b:Sphere;
		
		private var c3h6_carbon01:Sphere;
		private var c3h6_carbon02:Sphere;
		private var c3h6_carbon03:Sphere;
		private var c3h6_hydrogen01:Sphere;
		private var c3h6_hydrogen02:Sphere;
		private var c3h6_hydrogen03:Sphere;
		private var c3h6_hydrogen04:Sphere;
		private var c3h6_hydrogen05:Sphere;
		private var c3h6_hydrogen06:Sphere;
		private var c3h6_bond01:Cylinder;
		private var c3h6_bond02:Cylinder;
		private var c3h6_bond03:Cylinder;
		private var c3h6_bond04:Cylinder;
		private var c3h6_bond05:Cylinder;
		private var c3h6_bond06:Cylinder;
		private var c3h6_bond07:Cylinder;
		private var c3h6_bond08:Cylinder;
		private var c3h6_lobe01upper:DAE;
		private var c3h6_lobe01lower:DAE;
		private var c3h6_lobe02upper:DAE;
		private var c3h6_lobe02lower:DAE;
		private var c3h6_lobeConnect01upperA:Cylinder;
		private var c3h6_lobeConnect01lowerA:Cylinder;
		private var c3h6_lobeConnect01upperB:Cylinder;
		private var c3h6_lobeConnect01lowerB:Cylinder;
		private var c3h6_lobeConnect01upperC:Cylinder;
		private var c3h6_lobeConnect01lowerC:Cylinder;
		
		private var c2h2_carbon01:Sphere;
		private var c2h2_carbon02:Sphere;
		private var c2h2_hydrogen01:Sphere;
		private var c2h2_hydrogen02:Sphere;
		private var c2h2_bond01:Cylinder;
		private var c2h2_bond02:Cylinder;
		private var c2h2_bond03:Cylinder;
		private var c2h2_lobe01upper:DAE;
		private var c2h2_lobe01lower:DAE;
		private var c2h2_lobe02upper:DAE;
		private var c2h2_lobe02lower:DAE;
		private var c2h2_lobe03upper:DAE;
		private var c2h2_lobe03lower:DAE;
		private var c2h2_lobe04upper:DAE;
		private var c2h2_lobe04lower:DAE;
		private var c2h2_lobeConnect01upperA:Cylinder;
		private var c2h2_lobeConnect01lowerA:Cylinder;
		private var c2h2_lobeConnect01upperB:Cylinder;
		private var c2h2_lobeConnect01lowerB:Cylinder;
		private var c2h2_lobeConnect01upperC:Cylinder;
		private var c2h2_lobeConnect01lowerC:Cylinder;
		private var c2h2_lobeConnect02upperA:Cylinder;
		private var c2h2_lobeConnect02lowerA:Cylinder;
		private var c2h2_lobeConnect02upperB:Cylinder;
		private var c2h2_lobeConnect02lowerB:Cylinder;
		private var c2h2_lobeConnect02upperC:Cylinder;
		private var c2h2_lobeConnect02lowerC:Cylinder;
		
		private var c2h6_carbon01:Sphere;
		private var c2h6_carbon02:Sphere;
		private var c2h6_hydrogen01:Sphere;
		private var c2h6_hydrogen02:Sphere;
		private var c2h6_hydrogen03:Sphere;
		private var c2h6_hydrogen04:Sphere;
		private var c2h6_hydrogen05:Sphere;
		private var c2h6_hydrogen06:Sphere;
		private var c2h6_bond01:Cylinder;
		private var c2h6_bond02:Cylinder;
		private var c2h6_bond03:Cylinder;
		private var c2h6_bond04:Cylinder;
		private var c2h6_bond05:Cylinder;
		private var c2h6_bond06:Cylinder;
		private var c2h6_bond07:Cylinder;
		
		private var ch3conh2_carbon01:Sphere;
		private var ch3conh2_carbon02:Sphere;
		private var ch3conh2_oxygen01:Sphere;
		private var ch3conh2_hydrogen01:Sphere;
		private var ch3conh2_hydrogen02:Sphere;
		private var ch3conh2_hydrogen03:Sphere;
		private var ch3conh2_hydrogen04:Sphere;
		private var ch3conh2_hydrogen05:Sphere;
		private var ch3conh2_nitrogen01:Sphere;
		private var ch3conh2_electron01a:Sphere;
		private var ch3conh2_electron01b:Sphere;
		private var ch3conh2_electron02a:Sphere;
		private var ch3conh2_electron02b:Sphere;
		private var ch3conh2_electron03a:Sphere;
		private var ch3conh2_electron03b:Sphere;
		private var ch3conh2_bond01:Cylinder;
		private var ch3conh2_bond02:Cylinder;
		private var ch3conh2_bond03:Cylinder;
		private var ch3conh2_bond04:Cylinder;
		private var ch3conh2_bond05:Cylinder;
		private var ch3conh2_bond06:Cylinder;
		private var ch3conh2_bond07:Cylinder;
		private var ch3conh2_bond08:Cylinder;
		private var ch3conh2_bond09:Cylinder;
		private var ch3conh2_bond10:Cylinder;
		private var ch3conh2_bond11:Cylinder;
		private var ch3conh2_lobe01upper:DAE;
		private var ch3conh2_lobe01lower:DAE;
		private var ch3conh2_lobe02upper:DAE;
		private var ch3conh2_lobe02lower:DAE;
		private var ch3conh2_lobeConnect01upperA:Cylinder;
		private var ch3conh2_lobeConnect01lowerA:Cylinder;
		private var ch3conh2_lobeConnect01upperB:Cylinder;
		private var ch3conh2_lobeConnect01lowerB:Cylinder;
		private var ch3conh2_lobeConnect01upperC:Cylinder;
		private var ch3conh2_lobeConnect01lowerC:Cylinder;
		
		private var co2_carbon01:Sphere;
		private var co2_oxygen01:Sphere;
		private var co2_oxygen02:Sphere;
		private var co2_electron01a:Sphere;
		private var co2_electron01b:Sphere;
		private var co2_electron02a:Sphere;
		private var co2_electron02b:Sphere;
		private var co2_electron03a:Sphere;
		private var co2_electron03b:Sphere;
		private var co2_electron04a:Sphere;
		private var co2_electron04b:Sphere;
		private var co2_bond01:Cylinder;
		private var co2_bond02:Cylinder;
		private var co2_bond03:Cylinder;
		private var co2_bond04:Cylinder;
		private var co2_bond05:Cylinder;
		private var co2_bond06:Cylinder;
		private var co2_lobe01upper:DAE;
		private var co2_lobe01lower:DAE;
		private var co2_lobe02upper:DAE;
		private var co2_lobe02lower:DAE;
		private var co2_lobe03upper:DAE;
		private var co2_lobe03lower:DAE;
		private var co2_lobe04upper:DAE;
		private var co2_lobe04lower:DAE;
		private var co2_lobeConnect01upperA:Cylinder;
		private var co2_lobeConnect01lowerA:Cylinder;
		private var co2_lobeConnect01upperB:Cylinder;
		private var co2_lobeConnect01lowerB:Cylinder;
		private var co2_lobeConnect01upperC:Cylinder;
		private var co2_lobeConnect01lowerC:Cylinder;
		private var co2_lobeConnect02upperA:Cylinder;
		private var co2_lobeConnect02lowerA:Cylinder;
		private var co2_lobeConnect02upperB:Cylinder;
		private var co2_lobeConnect02lowerB:Cylinder;
		private var co2_lobeConnect02upperC:Cylinder;
		private var co2_lobeConnect02lowerC:Cylinder;
		
		private var c2h4_carbon01:Sphere;
		private var c2h4_carbon02:Sphere;
		private var c2h4_hydrogen01:Sphere;
		private var c2h4_hydrogen02:Sphere;
		private var c2h4_hydrogen03:Sphere;
		private var c2h4_hydrogen04:Sphere;
		private var c2h4_bond01:Cylinder;
		private var c2h4_bond02:Cylinder;
		private var c2h4_bond03:Cylinder;
		private var c2h4_bond04:Cylinder;
		private var c2h4_bond05:Cylinder;
		private var c2h4_lobe01upper:DAE;
		private var c2h4_lobe01lower:DAE;
		private var c2h4_lobe02upper:DAE;
		private var c2h4_lobe02lower:DAE;
		private var c2h4_lobeConnect01upperA:Cylinder;
		private var c2h4_lobeConnect01lowerA:Cylinder;
		private var c2h4_lobeConnect01upperB:Cylinder;
		private var c2h4_lobeConnect01lowerB:Cylinder;
		private var c2h4_lobeConnect01upperC:Cylinder;
		private var c2h4_lobeConnect01lowerC:Cylinder;
		
		private var ch3nh2_carbon01:Sphere;
		private var ch3nh2_nitrogen01:Sphere;
		private var ch3nh2_hydrogen01:Sphere;
		private var ch3nh2_hydrogen02:Sphere;
		private var ch3nh2_hydrogen03:Sphere;
		private var ch3nh2_hydrogen04:Sphere;
		private var ch3nh2_hydrogen05:Sphere;
		private var ch3nh2_electron01a:Sphere;
		private var ch3nh2_electron01b:Sphere;
		private var ch3nh2_bond01:Cylinder;
		private var ch3nh2_bond02:Cylinder;
		private var ch3nh2_bond03:Cylinder;
		private var ch3nh2_bond04:Cylinder;
		private var ch3nh2_bond05:Cylinder;
		private var ch3nh2_bond06:Cylinder;
		private var ch3nh2_bond07:Cylinder;
		
		private var of2_oxygen01:Sphere;
		private var of2_fluoride01:Sphere;
		private var of2_fluoride02:Sphere;
		private var of2_electron01a:Sphere;
		private var of2_electron01b:Sphere;
		private var of2_electron02a:Sphere;
		private var of2_electron02b:Sphere;
		private var of2_bond01:Cylinder;
		private var of2_bond02:Cylinder;
		private var of2_bond03:Cylinder;
		private var of2_bond04:Cylinder;
		private var of2_arrowDAE01:DAE;
		private var of2_arrowDAE02:DAE;
		
		private var sp_carbon01:Sphere;
		private var sp_electron01:Sphere;
		private var sp_electron02:Sphere;
		private var sp_bond01:Cylinder;
		private var sp_bond02:Cylinder;
		private var sp_lobe01upper:DAE;
		private var sp_lobe01lower:DAE;
		private var sp_lobe02upper:DAE;
		private var sp_lobe02lower:DAE;
		private var sp2_carbon01:Sphere;
		private var sp2_electron01:Sphere;
		private var sp2_electron02:Sphere;
		private var sp2_electron03:Sphere;
		private var sp2_bond01:Cylinder;
		private var sp2_bond02:Cylinder;
		private var sp2_bond03:Cylinder;
		private var sp2_lobe01upper:DAE;
		private var sp2_lobe01lower:DAE;
		private var sp3_carbon01:Sphere;
		private var sp3_bond01:Cylinder;
		private var sp3_bond02:Cylinder;
		private var sp3_bond03:Cylinder;
		private var sp3_bond04:Cylinder;
		private var sp3_electron01:Sphere;
		private var sp3_electron02:Sphere;
		private var sp3_electron03:Sphere;
		private var sp3_electron04:Sphere;
		
		private var m_00:Boolean;
		private var m_01:Boolean;
		private var m_02:Boolean;
		private var m_03:Boolean;
		private var m_04:Boolean;
		private var m_05:Boolean;
		private var m_06:Boolean;
		private var m_07:Boolean;
		private var m_08:Boolean;
		private var m_09:Boolean;
		private var m_10:Boolean;
		private var l_00:Loader;
		private var l_01:Loader;
		private var l_02:Loader;
		private var l_03:Loader;
		private var l_04:Loader;
		private var l_05:Loader;
		private var l_06:Loader;
		private var l_07:Loader;
		private var l_08:Loader;
		private var l_09:Loader;
		private var l_10:Loader;
		private var p_00:Sprite;
		private var p_01:Sprite; 
		private var p_02:Sprite; 
		private var p_03:Sprite; 
		private var p_04:Sprite; 
		private var p_05:Sprite; 
		private var p_06:Sprite; 
		private var p_07:Sprite; 
		private var p_08:Sprite; 
		private var p_09:Sprite;
		private var p_10:Sprite; 
		
		//private var ch4_shadowMat:BitmapFileMaterial;
		//private var ch4_shadow:Plane;
		
		
		public function Molecules_PV3D (numPatterns:uint, cameraParams:FLARParam, mirrorDisplay:Boolean, viewportWidth:Number, viewportHeight:Number) {
			this.bMirrorDisplay = mirrorDisplay;
			
			this.init(numPatterns);
			this.initPapervisionEnvironment(cameraParams, viewportWidth, viewportHeight);
			
			/*	==============================	Materials	==============================	*/
			redLobeEnv = new EnvMapMaterial(pointLight3D, BitmapAsset(new probeAsset()).bitmapData,BitmapAsset(new probeAsset()).bitmapData,0);
			blueLobeEnv = new EnvMapMaterial(pointLight3D, BitmapAsset(new blueProbeAsset()).bitmapData,BitmapAsset(new blueProbeAsset()).bitmapData,0);
			hydrogenMat = new BitmapFileMaterial("../resources/texture/h.jpg");
			carbonMat = new BitmapFileMaterial("../resources/texture/c.jpg");
			nitrogenMat = new BitmapFileMaterial("../resources/texture/n.jpg");
			oxygenMat = new BitmapFileMaterial("../resources/texture/o.jpg");
			fluorideMat = new BitmapFileMaterial("../resources/texture/f.jpg");
			//ch4_shadowMat = new BitmapFileMaterial("../resources/texture/ch4_shadow.png");
			bondMat = new ColorMaterial(0x0090ff, 0.65); // Bond color (Semi-transparent)
			electronMat = new ColorMaterial(0xff0000, 0.85); // Electron color (Semi-transparent)
			redArrowMat = new ColorMaterial(0xff0000, 1);
			yellowArrowMat = new ColorMaterial(0xffea00, 1);
			blueArrowMat = new ColorMaterial(0x0033ff, 1);
			redLobeMat = new MaterialsList();
			redLobeMat.addMaterial(redLobeEnv, "_2_-_Default");
			blueLobeMat = new MaterialsList();
			blueLobeMat.addMaterial(blueLobeEnv, "_2_-_Default");
			redArrow = new MaterialsList();
			redArrow.addMaterial(redArrowMat, "ColorMaterial_57E18F00");
			yellowArrow = new MaterialsList();
			yellowArrow.addMaterial(yellowArrowMat, "ColorMaterial_57E18F00");
			redLineMat = new LineMaterial(0xff0000, 1.0); // Red line material
			yellowLineMat = new LineMaterial(0xffea00, 1.0); // Yellow line material
			/*	==========================================================================	*/
			
			//	http://manewc.com/2008/05/15/manipulate-an-loader-object/
			l_00 = new Loader();  
			l_00.load(new URLRequest("../resources/texture/CH4-overlay.jpg"));  
			p_00 = new Sprite();
			addChild (p_00);
			p_00.addChild (l_00);
			p_00.x = 0;
			p_00.y = 450;
			p_00.visible = false;
			l_01 = new Loader(); 
			l_01.load(new URLRequest("../resources/texture/NH3-overlay.jpg"));
			p_01 = new Sprite();
			addChild (p_01);
			p_01.addChild (l_01);
			p_01.x = 0;
			p_01.y = 450;
			p_01.visible = false;
			l_02 = new Loader(); 
			l_02.load(new URLRequest("../resources/texture/CH3CHCH2-overlay.jpg"));
			p_02 = new Sprite();
			addChild (p_02);
			p_02.addChild (l_02);
			p_02.x = 0;
			p_02.y = 430;
			p_02.visible = false;
			l_03 = new Loader(); 
			l_03.load(new URLRequest("../resources/texture/C2H2-overlay.jpg"));
			p_03 = new Sprite();
			addChild (p_03);
			p_03.addChild (l_03);
			p_03.x = 0;
			p_03.y = 450;
			p_03.visible = false;
			l_04 = new Loader(); 
			l_04.load(new URLRequest("../resources/texture/C2H6-overlay.jpg"));
			p_04 = new Sprite();
			addChild (p_04);
			p_04.addChild (l_04);
			p_04.x = 0;
			p_04.y = 450;
			p_04.visible = false;
			l_05 = new Loader(); 
			l_05.load(new URLRequest("../resources/texture/CH3CONH2-overlay.jpg"));
			p_05 = new Sprite();
			addChild (p_05);
			p_05.addChild (l_05);
			p_05.x = 0;
			p_05.y = 400;
			p_05.visible = false;
			l_06 = new Loader(); 
			l_06.load(new URLRequest("../resources/texture/CO2-overlay.jpg"));
			p_06 = new Sprite();
			addChild (p_06);
			p_06.addChild (l_06);
			p_06.x = 0;
			p_06.y = 400;
			p_06.visible = false;
			l_07 = new Loader(); 
			l_07.load(new URLRequest("../resources/texture/C2H4-overlay.jpg"));
			p_07 = new Sprite();
			addChild (p_07);
			p_07.addChild (l_07);
			p_07.x = 0;
			p_07.y = 450;
			p_07.visible = false;
			l_08 = new Loader(); 
			l_08.load(new URLRequest("../resources/texture/CH3NH2-overlay.jpg"));
			p_08 = new Sprite();
			addChild (p_08);
			p_08.addChild (l_08);
			p_08.x = 0;
			p_08.y = 450;
			p_08.visible = false;
			l_09 = new Loader(); 
			l_09.load(new URLRequest("../resources/texture/OF2-overlay.jpg"));
			p_09 = new Sprite();
			addChild (p_09);
			p_09.addChild (l_09);
			p_09.x = 0;
			p_09.y = 450;
			p_09.visible = false;
			l_10 = new Loader(); 
			l_10.load(new URLRequest("../resources/texture/sp3sp2sp-overlay.jpg"));
			p_10 = new Sprite();
			addChild (p_10);
			p_10.addChild (l_10);
			p_10.x = 0;
			p_10.y = 400;
			p_10.visible = false;
			
			var _sphereSegs01:Number = new Number(9);
            var _sphereSegs02:Number = new Number(7);
            var _electronSegs01:Number = new Number(7);
            var _electronSegs02:Number = new Number(6);
            var _lobeConnectorSegs:Number = new Number(4);
            
            ch4_carbon01 = new Sphere(carbonMat, 12, _sphereSegs01, _sphereSegs02);
            ch4_carbon01.z = 0;            
        	ch4_carbon01.rotationX = 90;
        	ch4_hydrogen01 = new Sphere(hydrogenMat, 12, _sphereSegs01, _sphereSegs02);
        	ch4_hydrogen01.z = 50;
            ch4_hydrogen01.rotationX = 90;
            ch4_hydrogen02 = new Sphere(hydrogenMat, 12, _sphereSegs01, _sphereSegs02);
            ch4_hydrogen02.z = -17;
            ch4_hydrogen02.x = 47;
            ch4_hydrogen02.rotationX = 90;
            ch4_hydrogen03 = new Sphere(hydrogenMat, 12, _sphereSegs01, _sphereSegs02);
            ch4_hydrogen03.z = -17;
            ch4_hydrogen03.x = -23.5;
            ch4_hydrogen03.y = -40.7;
            ch4_hydrogen03.rotationX = 90;
            ch4_hydrogen04 = new Sphere(hydrogenMat, 12, _sphereSegs01, _sphereSegs02);
            ch4_hydrogen04.z = -17;
            ch4_hydrogen04.x = -23.5;
            ch4_hydrogen04.y = 40.7;
            ch4_hydrogen04.rotationX = 90;
            ch4_bond01 = new Cylinder(bondMat, 2.5, 25.5, 6, 1);
            ch4_bond01.z = 25;
            ch4_bond01.rotationX = 90;
            ch4_bond02 = new Cylinder(bondMat, 2.5, 25.5, 6, 1);
            ch4_bond02.z = -5.5;
            ch4_bond02.x = 23.5;
            ch4_bond02.rotationZ = 90;
            ch4_bond02.rotationX = 20;
            ch4_bond03 = new Cylinder(bondMat, 2.5, 25.5, 6, 1);
            ch4_bond03.z = -5.5;
            ch4_bond03.x = -12.5;
            ch4_bond03.y = -21.5;
            ch4_bond03.rotationZ = -30;
            ch4_bond03.rotationX = 20;
            ch4_bond04 = new Cylinder(bondMat, 2.5, 25.5, 6, 1);
            ch4_bond04.z = -5.5;
            ch4_bond04.x = -12.5;
            ch4_bond04.y = 21.5;
            ch4_bond04.rotationZ = -150;
            ch4_bond04.rotationX = 20;
            //ch4_shadow = new Plane(ch4_shadowMat, 200, 210);
            //ch4_shadow.z = -30;
            //ch4_shadow.rotationX = 180;
            ch4_carbon01.visible = false;
            ch4_hydrogen01.visible = false;
            ch4_hydrogen02.visible = false;
            ch4_hydrogen03.visible = false;
            ch4_hydrogen04.visible = false;
            ch4_bond01.visible = false;
            ch4_bond02.visible = false;
            ch4_bond03.visible = false;
            ch4_bond04.visible = false;
            //ch4_shadow.visible = false;
            
            nh3_nitrogen01 = new Sphere(nitrogenMat, 12, _sphereSegs01, _sphereSegs02);
            nh3_nitrogen01.rotationX = 90;
            nh3_hydrogen01 = new Sphere(hydrogenMat, 12, _sphereSegs01, _sphereSegs02);
            nh3_hydrogen01.rotationX = 90;
            nh3_hydrogen01.x = 43.3;
            nh3_hydrogen01.z = -25;
            nh3_hydrogen02 = new Sphere(hydrogenMat, 12, _sphereSegs01, _sphereSegs02);
            nh3_hydrogen02.rotationX = 90;
            nh3_hydrogen02.x = -21.65;
            nh3_hydrogen02.y = 37.5;
            nh3_hydrogen02.z = -25;
            nh3_hydrogen03 = new Sphere(hydrogenMat, 12, _sphereSegs01, _sphereSegs02);
            nh3_hydrogen03.rotationX = 90;
            nh3_hydrogen03.x = -21.65;
            nh3_hydrogen03.y = -37.5;
            nh3_hydrogen03.z = -25;
            nh3_bond01 = new Cylinder(bondMat, 2.5, 25.5, 6, 1);
            nh3_bond01.x = 21.65;
            nh3_bond01.z = -12.5;
            nh3_bond01.rotationX = 30;
            nh3_bond01.rotationZ = 90;
            nh3_bond02 = new Cylinder(bondMat, 2.5, 25.5, 6, 1);
            nh3_bond02.x = -10.825;
            nh3_bond02.y = -18.75;
            nh3_bond02.z = -12.5;
            nh3_bond02.rotationX = 30;
            nh3_bond02.rotationZ = -30;
            nh3_bond03 = new Cylinder(bondMat, 2.5, 25.5, 6, 1);
            nh3_bond03.x = -10.825;
            nh3_bond03.y = 18.75;
            nh3_bond03.z = -12.5;
            nh3_bond03.rotationX = 30;
            nh3_bond03.rotationZ = -150;
            nh3_bond04 = new Cylinder(bondMat, 2.5, 22.95, 6, 1);
            nh3_bond04.z = 22.95;
            nh3_bond04.rotationX = 90;
            nh3_electron01a = new Sphere(electronMat, 3.2, _electronSegs01, _electronSegs02);
			nh3_electron01a.x = 5.5;
			nh3_electron01a.z = 39.95;
			nh3_electron01b = new Sphere(electronMat, 3.2, _electronSegs01, _electronSegs02);
			nh3_electron01b.x = -5.5;
			nh3_electron01b.z = 39.95;
            nh3_nitrogen01.visible = false;
            nh3_hydrogen01.visible = false;
            nh3_hydrogen02.visible = false;
            nh3_hydrogen03.visible = false;
            nh3_bond01.visible = false;
            nh3_bond02.visible = false;
            nh3_bond03.visible = false;
            nh3_bond04.visible = false;
            nh3_electron01a.visible = false;
            nh3_electron01b.visible = false;
            
            c3h6_carbon01 = new Sphere(carbonMat, 12, _sphereSegs01, _sphereSegs02);
            c3h6_carbon01.rotationX = 90;
            c3h6_carbon02 = new Sphere(carbonMat, 12, _sphereSegs01, _sphereSegs02);
            c3h6_carbon02.rotationX = 90;
            c3h6_carbon02.x = -50;
			c3h6_carbon03 = new Sphere(carbonMat, 12, _sphereSegs01, _sphereSegs02);
			c3h6_carbon03.rotationX = 90;
			c3h6_carbon03.x = 25;
			c3h6_carbon03.y = 43.3;
			c3h6_hydrogen01 = new Sphere(hydrogenMat, 12, _sphereSegs01, _sphereSegs02);
			c3h6_hydrogen01.rotationX = 90;
			c3h6_hydrogen01.x = 25;
			c3h6_hydrogen01.y = -43.3;
			c3h6_hydrogen02 = new Sphere(hydrogenMat, 12, _sphereSegs01, _sphereSegs02);
			c3h6_hydrogen02.rotationX = 90;
			c3h6_hydrogen02.x = -75;
			c3h6_hydrogen02.y = -43.3;
			c3h6_hydrogen03 = new Sphere(hydrogenMat, 12, _sphereSegs01, _sphereSegs02);
			c3h6_hydrogen03.rotationX = 90;
			c3h6_hydrogen03.x = -75;
			c3h6_hydrogen03.y = 43.3;
			c3h6_hydrogen04 = new Sphere(hydrogenMat, 12, _sphereSegs01, _sphereSegs02);
			c3h6_hydrogen04.rotationX = 90;
			c3h6_hydrogen04.x = 33.5;
			c3h6_hydrogen04.y = 58.25;
			c3h6_hydrogen04.z = 47;
			c3h6_hydrogen05 = new Sphere(hydrogenMat, 12, _sphereSegs01, _sphereSegs02);
			c3h6_hydrogen05.rotationX = 90;
			c3h6_hydrogen05.x = -2.125;
			c3h6_hydrogen05.y = 77.7;
			c3h6_hydrogen05.z = -24.1;
			c3h6_hydrogen06 = new Sphere(hydrogenMat, 12, _sphereSegs01, _sphereSegs02);
			c3h6_hydrogen06.rotationX = 90;
			c3h6_hydrogen06.x = 68.35;
			c3h6_hydrogen06.y = 37.15;
			c3h6_hydrogen06.z = -24.1;
			c3h6_lobe01upper = new DAE();
			c3h6_lobe01upper.load("../resources/assets/lobe.DAE", redLobeMat);
			c3h6_lobe01upper.scale = 0.85;
			c3h6_lobe01upper.rotationX = 90;
			c3h6_lobe01upper.z = 32;
			c3h6_lobe01lower = new DAE();
			c3h6_lobe01lower.load("../resources/assets/lobe.DAE", redLobeMat);
			c3h6_lobe01lower.scale = 0.85;
			c3h6_lobe01lower.rotationX = 270;
			c3h6_lobe01lower.z = -32;
			c3h6_lobe02upper = new DAE();
			c3h6_lobe02upper.load("../resources/assets/lobe.DAE", redLobeMat);
			c3h6_lobe02upper.scale = 0.85;
			c3h6_lobe02upper.rotationX = 90;
			c3h6_lobe02upper.z = 32;
			c3h6_lobe02upper.x = -50;
			c3h6_lobe02lower = new DAE();
			c3h6_lobe02lower.load("../resources/assets/lobe.DAE", redLobeMat);
			c3h6_lobe02lower.scale = 0.85;
			c3h6_lobe02lower.rotationX = 270;
			c3h6_lobe02lower.z = -32;
			c3h6_lobe02lower.x = -50;
			c3h6_bond01 = new Cylinder(bondMat, 2.5, 25.5, 6, 1);
			c3h6_bond01.x = -25;
			c3h6_bond01.rotationZ = 90;
			c3h6_bond02 = new Cylinder(bondMat, 2.5, 25.5, 6, 1);
			c3h6_bond02.x = 12.5;
			c3h6_bond02.y = 21.65;
			c3h6_bond02.rotationZ = -30;
			c3h6_bond03 = new Cylinder(bondMat, 2.5, 25.5, 6, 1);
			c3h6_bond03.x = -62.5;
			c3h6_bond03.y = -21.65;
			c3h6_bond03.rotationZ = -30;
			c3h6_bond04 = new Cylinder(bondMat, 2.5, 25.5, 6, 1);
			c3h6_bond04.x = -62.5;
			c3h6_bond04.y = 21.65;
			c3h6_bond04.rotationZ = 30;
			c3h6_bond05 = new Cylinder(bondMat, 2.5, 25.5, 6, 1);
			c3h6_bond05.x = 12.5;
			c3h6_bond05.y = -21.65;
			c3h6_bond05.rotationZ = 30;
			c3h6_bond06 = new Cylinder(bondMat, 2.5, 25.5, 6, 1);
			c3h6_bond06.x = 29.25;
			c3h6_bond06.y = 50.85;
			c3h6_bond06.z = 23.45;
			c3h6_bond06.rotationX = 90;
			c3h6_bond06.rotationY = -20;
			c3h6_bond06.rotationZ = -120;
			c3h6_bond07 = new Cylinder(bondMat, 2.5, 25.5, 6, 1);
			c3h6_bond07.x = 11.45;
			c3h6_bond07.y = 60.5;
			c3h6_bond07.z = -12.05;
			c3h6_bond07.rotationX = 30.78;
			c3h6_bond07.rotationY = -171;
			c3h6_bond07.rotationZ = 43.24;
			c3h6_bond08 = new Cylinder(bondMat, 2.5, 25.5, 6, 1);
			c3h6_bond08.x = 46.68;
			c3h6_bond08.y = 40.3;
			c3h6_bond08.z = -12.05;
			c3h6_bond08.rotationX = 150.78;
			c3h6_bond08.rotationY = -171;
			c3h6_bond08.rotationZ = 76;
			c3h6_lobeConnect01upperA = new Cylinder(redArrowMat, 1, 6, _lobeConnectorSegs, 1);
			c3h6_lobeConnect01upperA.x = -25;
			c3h6_lobeConnect01upperA.z = 50;
			c3h6_lobeConnect01upperA.rotationZ = 90;
			c3h6_lobeConnect01upperB = new Cylinder(redArrowMat, 1, 6, _lobeConnectorSegs, 1);
			c3h6_lobeConnect01upperB.x = -15;
			c3h6_lobeConnect01upperB.z = 50;
			c3h6_lobeConnect01upperB.rotationZ = 90;
			c3h6_lobeConnect01upperC = new Cylinder(redArrowMat, 1, 6, _lobeConnectorSegs, 1);
			c3h6_lobeConnect01upperC.x = -35;
			c3h6_lobeConnect01upperC.z = 50;
			c3h6_lobeConnect01upperC.rotationZ = 90;
			c3h6_lobeConnect01lowerA = new Cylinder(redArrowMat, 1, 6, _lobeConnectorSegs, 1);
			c3h6_lobeConnect01lowerA.x = -25;
			c3h6_lobeConnect01lowerA.z = -50;
			c3h6_lobeConnect01lowerA.rotationZ = 90;
			c3h6_lobeConnect01lowerB = new Cylinder(redArrowMat, 1, 6, _lobeConnectorSegs, 1);
			c3h6_lobeConnect01lowerB.x = -15;
			c3h6_lobeConnect01lowerB.z = -50;
			c3h6_lobeConnect01lowerB.rotationZ = 90;
			c3h6_lobeConnect01lowerC = new Cylinder(redArrowMat, 1, 6, _lobeConnectorSegs, 1);
			c3h6_lobeConnect01lowerC.x = -35;
			c3h6_lobeConnect01lowerC.z = -50;
			c3h6_lobeConnect01lowerC.rotationZ = 90;
			c3h6_carbon01.visible = false;
			c3h6_carbon02.visible = false;
			c3h6_carbon03.visible = false;
			c3h6_hydrogen01.visible = false;
			c3h6_hydrogen02.visible = false;
			c3h6_hydrogen03.visible = false;
			c3h6_hydrogen04.visible = false;
			c3h6_hydrogen05.visible = false;
			c3h6_hydrogen06.visible = false;
			c3h6_lobe01upper.visible = false;
			c3h6_lobe01lower.visible = false;
			c3h6_lobe02upper.visible = false;
			c3h6_lobe02lower.visible = false;
			c3h6_bond01.visible = false;
			c3h6_bond02.visible = false;
			c3h6_bond03.visible = false;
			c3h6_bond04.visible = false;
			c3h6_bond05.visible = false;
			c3h6_bond06.visible = false;
			c3h6_bond07.visible = false;
			c3h6_bond08.visible = false;
			c3h6_lobeConnect01upperA.visible = false;
			c3h6_lobeConnect01lowerA.visible = false;
			c3h6_lobeConnect01upperB.visible = false;
			c3h6_lobeConnect01lowerB.visible = false;
			c3h6_lobeConnect01upperC.visible = false;
			c3h6_lobeConnect01lowerC.visible = false;
			
			c2h2_carbon01 = new Sphere(carbonMat, 12, _sphereSegs01, _sphereSegs02);
            c2h2_carbon01.rotationX = 90;
            c2h2_carbon01.x = -25;
            c2h2_carbon02 = new Sphere(carbonMat, 12, _sphereSegs01, _sphereSegs02);
            c2h2_carbon02.rotationX = 90;
            c2h2_carbon02.x = 25;
            c2h2_hydrogen01 = new Sphere(hydrogenMat, 12, _sphereSegs01, _sphereSegs02);
            c2h2_hydrogen01.rotationX = 90;
            c2h2_hydrogen01.x = -75;
            c2h2_hydrogen02 = new Sphere(hydrogenMat, 12, _sphereSegs01, _sphereSegs02);
            c2h2_hydrogen02.rotationX = 90;
            c2h2_hydrogen02.x = 75;
            c2h2_bond01 = new Cylinder(bondMat, 2.5, 25.5, 6, 1);
            c2h2_bond01.x = 0;
            c2h2_bond01.rotationZ = 90;
            c2h2_bond02 = new Cylinder(bondMat, 2.5, 25.5, 6, 1);
            c2h2_bond02.x = 50;
            c2h2_bond02.rotationZ = 90;
            c2h2_bond03 = new Cylinder(bondMat, 2.5, 25.5, 6, 1);
            c2h2_bond03.x = -50;
            c2h2_bond03.rotationZ = 90;
            c2h2_lobe01upper = new DAE();
            c2h2_lobe01upper.load("../resources/assets/lobe.DAE", redLobeMat);
            c2h2_lobe01upper.scale = 0.85;
            c2h2_lobe01upper.rotationX = 90;
            c2h2_lobe01upper.x = -25;
            c2h2_lobe01upper.z = 32;
            c2h2_lobe01lower = new DAE();
            c2h2_lobe01lower.load("../resources/assets/lobe.DAE", redLobeMat);
            c2h2_lobe01lower.scale = 0.85;
            c2h2_lobe01lower.rotationX = 270;
            c2h2_lobe01lower.x = -25;
            c2h2_lobe01lower.z = -32;
            c2h2_lobe02upper = new DAE();
            c2h2_lobe02upper.load("../resources/assets/lobe.DAE", redLobeMat);
            c2h2_lobe02upper.scale = 0.85;
            c2h2_lobe02upper.rotationX = 90;
            c2h2_lobe02upper.z = 32;
            c2h2_lobe02upper.x = 25;
            c2h2_lobe02lower = new DAE();
            c2h2_lobe02lower.load("../resources/assets/lobe.DAE", redLobeMat);
            c2h2_lobe02lower.scale = 0.85;
            c2h2_lobe02lower.rotationX = 270;
            c2h2_lobe02lower.z = -32;
            c2h2_lobe02lower.x = 25;
            c2h2_lobe03upper = new DAE();
            c2h2_lobe03upper.load("../resources/assets/lobe.DAE", blueLobeMat);
            c2h2_lobe03upper.scale = 0.85;
            c2h2_lobe03upper.y = 32;
            c2h2_lobe03upper.x = -25;
            c2h2_lobe03lower = new DAE();
            c2h2_lobe03lower.load("../resources/assets/lobe.DAE", blueLobeMat);
            c2h2_lobe03lower.scale = 0.85;
            c2h2_lobe03lower.rotationX = 180;
            c2h2_lobe03lower.y = -32;
            c2h2_lobe03lower.x = -25;
            c2h2_lobe04upper = new DAE();
            c2h2_lobe04upper.load("../resources/assets/lobe.DAE", blueLobeMat);
            c2h2_lobe04upper.scale = 0.85;
            c2h2_lobe04upper.y = 32;
            c2h2_lobe04upper.x = 25;
            c2h2_lobe04lower = new DAE();
            c2h2_lobe04lower.load("../resources/assets/lobe.DAE", blueLobeMat);
            c2h2_lobe04lower.scale = 0.85;
            c2h2_lobe04lower.rotationX = 180;
            c2h2_lobe04lower.y = -32;
            c2h2_lobe04lower.x = 25;
            c2h2_lobeConnect01upperA = new Cylinder(redArrowMat, 1, 6, _lobeConnectorSegs, 1);
			c2h2_lobeConnect01upperA.x = 0;
			c2h2_lobeConnect01upperA.z = 50;
			c2h2_lobeConnect01upperA.rotationZ = 90;
			c2h2_lobeConnect01upperB = new Cylinder(redArrowMat, 1, 6, _lobeConnectorSegs, 1);
			c2h2_lobeConnect01upperB.x = -10;
			c2h2_lobeConnect01upperB.z = 50;
			c2h2_lobeConnect01upperB.rotationZ = 90;
			c2h2_lobeConnect01upperC = new Cylinder(redArrowMat, 1, 6, _lobeConnectorSegs, 1);
			c2h2_lobeConnect01upperC.x = 10;
			c2h2_lobeConnect01upperC.z = 50;
			c2h2_lobeConnect01upperC.rotationZ = 90;
			c2h2_lobeConnect01lowerA = new Cylinder(redArrowMat, 1, 6, _lobeConnectorSegs, 1);
			c2h2_lobeConnect01lowerA.x = 0;
			c2h2_lobeConnect01lowerA.z = -50;
			c2h2_lobeConnect01lowerA.rotationZ = 90;
			c2h2_lobeConnect01lowerB = new Cylinder(redArrowMat, 1, 6, _lobeConnectorSegs, 1);
			c2h2_lobeConnect01lowerB.x = -10;
			c2h2_lobeConnect01lowerB.z = -50;
			c2h2_lobeConnect01lowerB.rotationZ = 90;
			c2h2_lobeConnect01lowerC = new Cylinder(redArrowMat, 1, 6, _lobeConnectorSegs, 1);
			c2h2_lobeConnect01lowerC.x = 10;
			c2h2_lobeConnect01lowerC.z = -50;
			c2h2_lobeConnect01lowerC.rotationZ = 90;
			c2h2_lobeConnect02upperA = new Cylinder(blueArrowMat, 1, 6, _lobeConnectorSegs, 1);
			c2h2_lobeConnect02upperA.x = 0;
			c2h2_lobeConnect02upperA.y = 50;
			c2h2_lobeConnect02upperA.rotationZ = 90;
			c2h2_lobeConnect02upperB = new Cylinder(blueArrowMat, 1, 6, _lobeConnectorSegs, 1);
			c2h2_lobeConnect02upperB.x = -10;
			c2h2_lobeConnect02upperB.y = 50;
			c2h2_lobeConnect02upperB.rotationZ = 90;
			c2h2_lobeConnect02upperC = new Cylinder(blueArrowMat, 1, 6, _lobeConnectorSegs, 1);
			c2h2_lobeConnect02upperC.x = 10;
			c2h2_lobeConnect02upperC.y = 50;
			c2h2_lobeConnect02upperC.rotationZ = 90;
			c2h2_lobeConnect02lowerA = new Cylinder(blueArrowMat, 1, 6, _lobeConnectorSegs, 1);
			c2h2_lobeConnect02lowerA.x = 0;
			c2h2_lobeConnect02lowerA.y = -50;
			c2h2_lobeConnect02lowerA.rotationZ = 90;
			c2h2_lobeConnect02lowerB = new Cylinder(blueArrowMat, 1, 6, _lobeConnectorSegs, 1);
			c2h2_lobeConnect02lowerB.x = -10;
			c2h2_lobeConnect02lowerB.y = -50;
			c2h2_lobeConnect02lowerB.rotationZ = 90;
			c2h2_lobeConnect02lowerC = new Cylinder(blueArrowMat, 1, 6, _lobeConnectorSegs, 1);
			c2h2_lobeConnect02lowerC.x = 10;
			c2h2_lobeConnect02lowerC.y = -50;
			c2h2_lobeConnect02lowerC.rotationZ = 90;
            c2h2_carbon01.visible = false;
            c2h2_carbon02.visible = false;
            c2h2_hydrogen01.visible = false;
            c2h2_hydrogen02.visible = false;
            c2h2_bond01.visible = false;
            c2h2_bond02.visible = false;
            c2h2_bond03.visible = false;
            c2h2_lobe01upper.visible = false;
            c2h2_lobe01lower.visible = false;
            c2h2_lobe02upper.visible = false;
            c2h2_lobe02lower.visible = false;
            c2h2_lobe03upper.visible = false;
            c2h2_lobe03lower.visible = false;
            c2h2_lobe04upper.visible = false;
            c2h2_lobe04lower.visible = false;
            c2h2_lobeConnect01upperA.visible = false;
            c2h2_lobeConnect01upperB.visible = false;
            c2h2_lobeConnect01upperC.visible = false;
            c2h2_lobeConnect01lowerA.visible = false;
            c2h2_lobeConnect01lowerB.visible = false;
            c2h2_lobeConnect01lowerC.visible = false;
            c2h2_lobeConnect02upperA.visible = false;
            c2h2_lobeConnect02upperB.visible = false;
            c2h2_lobeConnect02upperC.visible = false;
            c2h2_lobeConnect02lowerA.visible = false;
            c2h2_lobeConnect02lowerB.visible = false;
            c2h2_lobeConnect02lowerC.visible = false;
            
            c2h6_carbon01 = new Sphere(carbonMat, 12, _sphereSegs01, _sphereSegs02);
			c2h6_carbon01.rotationX = 90;
			c2h6_carbon01.rotationZ = 90;
			c2h6_carbon02 = new Sphere(carbonMat, 12, _sphereSegs01, _sphereSegs02);
			c2h6_carbon02.rotationX = 90;
			c2h6_carbon02.rotationZ = 90;
			c2h6_hydrogen01 = new Sphere(hydrogenMat, 12, _sphereSegs01, _sphereSegs02);
			c2h6_hydrogen01.z = 47;
			c2h6_hydrogen01.y = -17;
			c2h6_hydrogen01.rotationX = 90;
			c2h6_hydrogen01.rotationZ = 90;
			c2h6_hydrogen02 = new Sphere(hydrogenMat, 12, _sphereSegs01, _sphereSegs02);
			c2h6_hydrogen02.z = -23.5;
			c2h6_hydrogen02.y = -17;
			c2h6_hydrogen02.x = 40.7;
			c2h6_hydrogen02.rotationX = 90;
			c2h6_hydrogen02.rotationZ = 90;
			c2h6_hydrogen03 = new Sphere(hydrogenMat, 12, _sphereSegs01, _sphereSegs02);
			c2h6_hydrogen03.z = -23.5;
			c2h6_hydrogen03.y = -17;
			c2h6_hydrogen03.x = -40.7;
			c2h6_hydrogen03.rotationX = 90;
			c2h6_hydrogen03.rotationZ = 90;
			c2h6_hydrogen04 = new Sphere(hydrogenMat, 12, _sphereSegs01, _sphereSegs02);
			c2h6_hydrogen04.z = 23.5;
			c2h6_hydrogen04.y = 17;
			c2h6_hydrogen04.x = -40.7;
			c2h6_hydrogen04.rotationX = 90;
			c2h6_hydrogen04.rotationZ = 90;
			c2h6_hydrogen05 = new Sphere(hydrogenMat, 12, _sphereSegs01, _sphereSegs02);
			c2h6_hydrogen05.z = 23.5;
			c2h6_hydrogen05.y = 17;
			c2h6_hydrogen05.x = 40.7;
			c2h6_hydrogen05.rotationX = 90;
			c2h6_hydrogen05.rotationZ = 90;
			c2h6_hydrogen06 = new Sphere(hydrogenMat, 12, _sphereSegs01, _sphereSegs02);
			c2h6_hydrogen06.z = -47;
			c2h6_hydrogen06.y = 17;
			c2h6_hydrogen06.rotationX = 90;
			c2h6_hydrogen06.rotationZ = 90;
			c2h6_bond01 = new Cylinder(bondMat, 2.5, 25.5, 6, 1);
			c2h6_bond02 = new Cylinder(bondMat, 2.5, 25.5, 6, 1);
			c2h6_bond02.z = 23.5;
			c2h6_bond02.y = -8.5;
			c2h6_bond02.rotationX = -70;
			c2h6_bond03 = new Cylinder(bondMat, 2.5, 25.5, 6, 1);
			c2h6_bond03.z = -11.5;
			c2h6_bond03.y = -8.5;
			c2h6_bond03.x = -20.5;
			c2h6_bond03.rotationX = 70;
			c2h6_bond03.rotationY = 60;
			c2h6_bond04 = new Cylinder(bondMat, 2.5, 25.5, 6, 1);
			c2h6_bond04.z = -11.5;
			c2h6_bond04.y = -8.5;
			c2h6_bond04.x = 20.5;
			c2h6_bond04.rotationX = 70;
			c2h6_bond04.rotationY = -60;
			c2h6_bond05 = new Cylinder(bondMat, 2.5, 25.5, 6, 1);
			c2h6_bond05.z = -23.5;
			c2h6_bond05.y = 8.5;
			c2h6_bond05.rotationX = -70;
			c2h6_bond06 = new Cylinder(bondMat, 2.5, 25.5, 6, 1);
			c2h6_bond06.z = 11.5;
			c2h6_bond06.y = 8.5;
			c2h6_bond06.x = -20.5;
			c2h6_bond06.rotationX = 70;
			c2h6_bond06.rotationY = -60;
			c2h6_bond07 = new Cylinder(bondMat, 2.5, 25.5, 6, 1);
			c2h6_bond07.z = 11.5;
			c2h6_bond07.y = 8.5;
			c2h6_bond07.x = 20.5;
			c2h6_bond07.rotationX = 70;
			c2h6_bond07.rotationY = 60;
			c2h6_carbon01.visible = false;
			c2h6_carbon02.visible = false;
			c2h6_hydrogen01.visible = false;
			c2h6_hydrogen02.visible = false;
			c2h6_hydrogen03.visible = false;
			c2h6_hydrogen04.visible = false;
			c2h6_hydrogen05.visible = false;
			c2h6_hydrogen06.visible = false;
			c2h6_bond01.visible = false;
			c2h6_bond02.visible = false;
			c2h6_bond03.visible = false;
			c2h6_bond04.visible = false;
			c2h6_bond05.visible = false;
			c2h6_bond06.visible = false;
			c2h6_bond07.visible = false;
			
			ch3conh2_carbon01 = new Sphere(carbonMat, 12, _sphereSegs01, _sphereSegs02);
			ch3conh2_carbon01.rotationX = 90;
			ch3conh2_carbon02 = new Sphere(carbonMat, 12, _sphereSegs01, _sphereSegs02);
			ch3conh2_carbon02.rotationX = 90;
			ch3conh2_carbon02.x = 25;
			ch3conh2_carbon02.y = 43.3;
			ch3conh2_oxygen01 = new Sphere(oxygenMat, 12, _sphereSegs01, _sphereSegs02);
			ch3conh2_oxygen01.rotationX = 90;
			ch3conh2_oxygen01.x = -50;
			ch3conh2_hydrogen01 = new Sphere(hydrogenMat, 12, _sphereSegs01, _sphereSegs02);
			ch3conh2_hydrogen01.rotationX = 90;
			ch3conh2_hydrogen01.x = 33.5;
			ch3conh2_hydrogen01.y = 58.25;
			ch3conh2_hydrogen01.z = 47;
			ch3conh2_hydrogen02 = new Sphere(hydrogenMat, 12, _sphereSegs01, _sphereSegs02);
			ch3conh2_hydrogen02.rotationX = 90;
			ch3conh2_hydrogen02.x = 33.5;
			ch3conh2_hydrogen02.y = -58.25;
			ch3conh2_hydrogen02.z = 47;
			ch3conh2_hydrogen03 = new Sphere(hydrogenMat, 12, _sphereSegs01, _sphereSegs02);
			ch3conh2_hydrogen03.rotationX = 90;
			ch3conh2_hydrogen03.x = 68.35;
			ch3conh2_hydrogen03.y = -37.15;
			ch3conh2_hydrogen03.z = -24.1;
			ch3conh2_hydrogen04 = new Sphere(hydrogenMat, 12, _sphereSegs01, _sphereSegs02);
			ch3conh2_hydrogen04.rotationX = 90;
			ch3conh2_hydrogen04.x = 68.35;
			ch3conh2_hydrogen04.y = 37.15;
			ch3conh2_hydrogen04.z = -24.1;
			ch3conh2_hydrogen05 = new Sphere(hydrogenMat, 12, _sphereSegs01, _sphereSegs02);
			ch3conh2_hydrogen05.rotationX = 90;
			ch3conh2_hydrogen05.x = -2.125;
			ch3conh2_hydrogen05.y = 77.7;
			ch3conh2_hydrogen05.z = -24.1;
			ch3conh2_nitrogen01 = new Sphere(nitrogenMat, 12, _sphereSegs01, _sphereSegs02);
			ch3conh2_nitrogen01.rotationX = 90;
			ch3conh2_nitrogen01.x = 25;
			ch3conh2_nitrogen01.y = -43.3;			
			ch3conh2_electron01a = new Sphere(electronMat, 3.2, _electronSegs01, _electronSegs02);
			ch3conh2_electron01a.x = 5.5;
			ch3conh2_electron01b = new Sphere(electronMat, 3.2, _electronSegs01, _electronSegs02);
			ch3conh2_electron01b.x = -5.5;
			ch3conh2_electron02a = new Sphere(electronMat, 3.2, _electronSegs01, _electronSegs02);
			ch3conh2_electron02a.x = 5.5;
			ch3conh2_electron02b = new Sphere(electronMat, 3.2, _electronSegs01, _electronSegs02);
			ch3conh2_electron02b.x = -5.5;
			ch3conh2_electron03a = new Sphere(electronMat, 3.2, _electronSegs01, _electronSegs02);
			ch3conh2_electron03a.x = 5.5;
			ch3conh2_electron03b = new Sphere(electronMat, 3.2, _electronSegs01, _electronSegs02);
			ch3conh2_electron03b.x = -5.5;
			ch3conh2_bond01 = new Cylinder(bondMat, 2.5, 25.5, 6, 1);
			ch3conh2_bond01.x = -25;
			ch3conh2_bond01.rotationZ = 90;
			ch3conh2_bond02 = new Cylinder(bondMat, 2.5, 25.5, 6, 1);
			ch3conh2_bond02.x = 12.5;
			ch3conh2_bond02.y = 21.65;
			ch3conh2_bond02.rotationZ = -30;
			ch3conh2_bond03 = new Cylinder(bondMat, 2.5, 25.5, 6, 1);
			ch3conh2_bond03.x = -62.5;
			ch3conh2_bond03.y = -21.65;
			ch3conh2_bond03.rotationZ = -30;
			ch3conh2_bond04 = new Cylinder(bondMat, 2.5, 25.5, 6, 1);
			ch3conh2_bond04.x = -62.5;
			ch3conh2_bond04.y = 21.65;
			ch3conh2_bond04.rotationZ = 30;
			ch3conh2_bond05 = new Cylinder(bondMat, 2.5, 25.5, 6, 1);
			ch3conh2_bond05.x = 12.5;
			ch3conh2_bond05.y = -21.65;
			ch3conh2_bond05.rotationZ = 30;
			ch3conh2_bond06 = new Cylinder(bondMat, 2.5, 25.5, 6, 1);
			ch3conh2_bond06.x = 29.25;
			ch3conh2_bond06.y = 50.85;
			ch3conh2_bond06.z = 23.45;
			ch3conh2_bond06.rotationX = 90;
			ch3conh2_bond06.rotationY = -20;
			ch3conh2_bond06.rotationZ = -120;
			ch3conh2_bond07 = new Cylinder(bondMat, 2.5, 25.5, 6, 1);
			ch3conh2_bond07.x = 11.45;
			ch3conh2_bond07.y = 60.5;
			ch3conh2_bond07.z = -12.05;
			ch3conh2_bond07.rotationX = 30.78;
			ch3conh2_bond07.rotationY = -171;
			ch3conh2_bond07.rotationZ = 43.24;
			ch3conh2_bond08 = new Cylinder(bondMat, 2.5, 25.5, 6, 1);
			ch3conh2_bond08.x = 46.68;
			ch3conh2_bond08.y = 40.3;
			ch3conh2_bond08.z = -12.05;
			ch3conh2_bond08.rotationX = 150.78;
			ch3conh2_bond08.rotationY = -171;
			ch3conh2_bond08.rotationZ = 76;
			ch3conh2_bond09 = new Cylinder(bondMat, 2.5, 25.5, 6, 1);
			ch3conh2_bond09.x = 29.25;
			ch3conh2_bond09.y = -50.85;
			ch3conh2_bond09.z = 23.45;
			ch3conh2_bond09.rotationX = 90;
			ch3conh2_bond09.rotationY = -20;
			ch3conh2_bond09.rotationZ = -210;
			ch3conh2_bond10 = new Cylinder(bondMat, 2.5, 25.5, 6, 1);
			ch3conh2_bond10.x = 11.45;
			ch3conh2_bond10.y = -60.5;
			ch3conh2_bond10.z = -12.05;
			ch3conh2_bond10.rotationX = -30.78;
			ch3conh2_bond10.rotationY = 171;
			ch3conh2_bond10.rotationZ = -43.24;
			ch3conh2_bond11 = new Cylinder(bondMat, 2.5, 25.5, 6, 1);
			ch3conh2_bond11.x = 46.68;
			ch3conh2_bond11.y = -40.3;
			ch3conh2_bond11.z = -12.05;
			ch3conh2_bond11.rotationX = -150.78;
			ch3conh2_bond11.rotationY = 171;
			ch3conh2_bond11.rotationZ = -76;
			ch3conh2_lobe01upper = new DAE();
            ch3conh2_lobe01upper.load("../resources/assets/lobe.DAE", redLobeMat);
            ch3conh2_lobe01upper.scale = 0.85;
            ch3conh2_lobe01upper.rotationX = 90;
            ch3conh2_lobe01upper.z = 32;
            ch3conh2_lobe01lower = new DAE();
            ch3conh2_lobe01lower.load("../resources/assets/lobe.DAE", redLobeMat);
            ch3conh2_lobe01lower.scale = 0.85;
            ch3conh2_lobe01lower.rotationX = 270;
            ch3conh2_lobe01lower.z = -32;
            ch3conh2_lobe02upper = new DAE();
            ch3conh2_lobe02upper.load("../resources/assets/lobe.DAE", redLobeMat);
            ch3conh2_lobe02upper.scale = 0.85;
            ch3conh2_lobe02upper.rotationX = 90;
            ch3conh2_lobe02upper.z = 32;
            ch3conh2_lobe02upper.x = -50;
            ch3conh2_lobe02lower = new DAE();
            ch3conh2_lobe02lower.load("../resources/assets/lobe.DAE", redLobeMat);
            ch3conh2_lobe02lower.scale = 0.85;
            ch3conh2_lobe02lower.rotationX = 270;
            ch3conh2_lobe02lower.z = -32;
            ch3conh2_lobe02lower.x = -50;
            ch3conh2_lobeConnect01upperA = new Cylinder(redArrowMat, 1, 6, _lobeConnectorSegs, 1);
			ch3conh2_lobeConnect01upperA.x = -25;
			ch3conh2_lobeConnect01upperA.z = 50;
			ch3conh2_lobeConnect01upperA.rotationZ = 90;
			ch3conh2_lobeConnect01upperB = new Cylinder(redArrowMat, 1, 6, _lobeConnectorSegs, 1);
			ch3conh2_lobeConnect01upperB.x = -15;
			ch3conh2_lobeConnect01upperB.z = 50;
			ch3conh2_lobeConnect01upperB.rotationZ = 90;
			ch3conh2_lobeConnect01upperC = new Cylinder(redArrowMat, 1, 6, _lobeConnectorSegs, 1);
			ch3conh2_lobeConnect01upperC.x = -35;
			ch3conh2_lobeConnect01upperC.z = 50;
			ch3conh2_lobeConnect01upperC.rotationZ = 90;
			ch3conh2_lobeConnect01lowerA = new Cylinder(redArrowMat, 1, 6, _lobeConnectorSegs, 1);
			ch3conh2_lobeConnect01lowerA.x = -25;
			ch3conh2_lobeConnect01lowerA.z = -50;
			ch3conh2_lobeConnect01lowerA.rotationZ = 90;
			ch3conh2_lobeConnect01lowerB = new Cylinder(redArrowMat, 1, 6, _lobeConnectorSegs, 1);
			ch3conh2_lobeConnect01lowerB.x = -15;
			ch3conh2_lobeConnect01lowerB.z = -50;
			ch3conh2_lobeConnect01lowerB.rotationZ = 90;
			ch3conh2_lobeConnect01lowerC = new Cylinder(redArrowMat, 1, 6, _lobeConnectorSegs, 1);
			ch3conh2_lobeConnect01lowerC.x = -35;
			ch3conh2_lobeConnect01lowerC.z = -50;
			ch3conh2_lobeConnect01lowerC.rotationZ = 90;
            ch3conh2_carbon01.visible = false;
            ch3conh2_carbon02.visible = false;
            ch3conh2_oxygen01.visible = false;
            ch3conh2_hydrogen01.visible = false;
            ch3conh2_hydrogen02.visible = false;
            ch3conh2_hydrogen03.visible = false;
            ch3conh2_hydrogen04.visible = false;
            ch3conh2_hydrogen05.visible = false;
            ch3conh2_nitrogen01.visible = false;
            ch3conh2_electron01a.visible = false;
            ch3conh2_electron01b.visible = false;
            ch3conh2_electron02a.visible = false;
            ch3conh2_electron02b.visible = false;
            ch3conh2_electron03a.visible = false;
            ch3conh2_electron03b.visible = false;
            ch3conh2_bond01.visible = false;
            ch3conh2_bond02.visible = false;
            ch3conh2_bond03.visible = false;
            ch3conh2_bond04.visible = false;
            ch3conh2_bond05.visible = false;
            ch3conh2_bond06.visible = false;
            ch3conh2_bond07.visible = false;
            ch3conh2_bond08.visible = false;
            ch3conh2_bond09.visible = false;
            ch3conh2_bond10.visible = false;
            ch3conh2_bond11.visible = false;
            ch3conh2_lobe01upper.visible = false;
            ch3conh2_lobe01lower.visible = false;
            ch3conh2_lobe02upper.visible = false;
            ch3conh2_lobe02lower.visible = false;
            ch3conh2_lobeConnect01upperA.visible = false;
            ch3conh2_lobeConnect01upperB.visible = false;
            ch3conh2_lobeConnect01upperC.visible = false;
            ch3conh2_lobeConnect01lowerA.visible = false;
            ch3conh2_lobeConnect01lowerB.visible = false;
            ch3conh2_lobeConnect01lowerC.visible = false;
            
            co2_carbon01 = new Sphere(carbonMat, 12, _sphereSegs01, _sphereSegs02);
			co2_carbon01.rotationX = 90;
			co2_oxygen01 = new Sphere(oxygenMat, 12, _sphereSegs01, _sphereSegs02);
			co2_oxygen01.rotationX = 90;
			co2_oxygen01.x = -50;
			co2_oxygen02 = new Sphere(oxygenMat, 12, _sphereSegs01, _sphereSegs02);
			co2_oxygen02.rotationX = 90;
			co2_oxygen02.x = 50;
			co2_electron01a = new Sphere(electronMat, 3.2, _electronSegs01, _electronSegs02);
			co2_electron01a.x = 5.5;
			co2_electron01b = new Sphere(electronMat, 3.2, _electronSegs01, _electronSegs02);
			co2_electron01b.x = -5.5;
			co2_electron02a = new Sphere(electronMat, 3.2, _electronSegs01, _electronSegs02);
			co2_electron02a.x = 5.5;
			co2_electron02b = new Sphere(electronMat, 3.2, _electronSegs01, _electronSegs02);
			co2_electron02b.x = -5.5;
			co2_electron03a = new Sphere(electronMat, 3.2, _electronSegs01, _electronSegs02);
			co2_electron03a.x = 5.5;
			co2_electron03b = new Sphere(electronMat, 3.2, _electronSegs01, _electronSegs02);
			co2_electron03b.x = -5.5;
			co2_electron04a = new Sphere(electronMat, 3.2, _electronSegs01, _electronSegs02);
			co2_electron04a.x = 5.5;
			co2_electron04b = new Sphere(electronMat, 3.2, _electronSegs01, _electronSegs02);
			co2_electron04b.x = -5.5;
			co2_bond01 = new Cylinder(bondMat, 2.5, 25.5, 6, 1);
			co2_bond01.x = -62.5;
			co2_bond01.z = 21.7;
			co2_bond01.rotationX = 60;
			co2_bond01.rotationZ = 90;
			co2_bond02 = new Cylinder(bondMat, 2.5, 25.5, 6, 1);
			co2_bond02.x = -62.5;
			co2_bond02.z = -21.7;
			co2_bond02.rotationX = -60;
			co2_bond02.rotationZ = 90;
			co2_bond03 = new Cylinder(bondMat, 2.5, 25.5, 6, 1);
			co2_bond03.x = -25;
			co2_bond03.rotationZ = 90;
			co2_bond04 = new Cylinder(bondMat, 2.5, 25.5, 6, 1);
			co2_bond04.x = 25;
			co2_bond04.rotationZ = 90;
			co2_bond05 = new Cylinder(bondMat, 2.5, 25.5, 6, 1);
			co2_bond05.x = 62.5;
			co2_bond05.y = -21.7;
			co2_bond05.rotationX = 90;
			co2_bond05.rotationY = 90;
			co2_bond05.rotationZ = -60;
			co2_bond06 = new Cylinder(bondMat, 2.5, 25.5, 6, 1);
			co2_bond06.x = 62.5;
			co2_bond06.y = 21.7;
			co2_bond06.rotationX = -90;
			co2_bond06.rotationY = 90;
			co2_bond06.rotationZ = -120;
			co2_lobe01upper = new DAE();
			co2_lobe01upper.load("../resources/assets/lobe.DAE", redLobeMat);
			co2_lobe01upper.scale = 0.85;
			co2_lobe01upper.rotationX = 90;
			co2_lobe01upper.z = 32;
			co2_lobe01lower = new DAE();
			co2_lobe01lower.load("../resources/assets/lobe.DAE", redLobeMat);
			co2_lobe01lower.scale = 0.85;
			co2_lobe01lower.rotationX = 270;
			co2_lobe01lower.z = -32;
			co2_lobe02upper = new DAE();
			co2_lobe02upper.load("../resources/assets/lobe.DAE", redLobeMat);
			co2_lobe02upper.scale = 0.85;
			co2_lobe02upper.rotationX = 90;
			co2_lobe02upper.z = 32;
			co2_lobe02upper.x = 50;
			co2_lobe02lower = new DAE();
			co2_lobe02lower.load("../resources/assets/lobe.DAE", redLobeMat);
			co2_lobe02lower.scale = 0.85;
			co2_lobe02lower.rotationX = 270;
			co2_lobe02lower.z = -32;
			co2_lobe02lower.x = 50;
			co2_lobe03upper = new DAE();
			co2_lobe03upper.load("../resources/assets/lobe.DAE", blueLobeMat);
			co2_lobe03upper.scale = 0.85;
			co2_lobe03upper.y = 32;
			co2_lobe03upper.x = -50;
			co2_lobe03lower = new DAE();
			co2_lobe03lower.load("../resources/assets/lobe.DAE", blueLobeMat);
			co2_lobe03lower.scale = 0.85;
			co2_lobe03lower.rotationX = 180;
			co2_lobe03lower.y = -32;
			co2_lobe03lower.x = -50;
			co2_lobe04upper = new DAE();
			co2_lobe04upper.load("../resources/assets/lobe.DAE", blueLobeMat);
			co2_lobe04upper.scale = 0.85;
			co2_lobe04upper.y = 32;
			co2_lobe04lower = new DAE();
			co2_lobe04lower.load("../resources/assets/lobe.DAE", blueLobeMat);
			co2_lobe04lower.scale = 0.85;
			co2_lobe04lower.rotationX = 180;
			co2_lobe04lower.y = -32;
			co2_lobeConnect01upperA = new Cylinder(redArrowMat, 1, 6, _lobeConnectorSegs, 1);
			co2_lobeConnect01upperA.x = 25;
			co2_lobeConnect01upperA.z = 50;
			co2_lobeConnect01upperA.rotationZ = 90;
			co2_lobeConnect01upperB = new Cylinder(redArrowMat, 1, 6, _lobeConnectorSegs, 1);
			co2_lobeConnect01upperB.x = 35;
			co2_lobeConnect01upperB.z = 50;
			co2_lobeConnect01upperB.rotationZ = 90;
			co2_lobeConnect01upperC = new Cylinder(redArrowMat, 1, 6, _lobeConnectorSegs, 1);
			co2_lobeConnect01upperC.x = 15;
			co2_lobeConnect01upperC.z = 50;
			co2_lobeConnect01upperC.rotationZ = 90;
			co2_lobeConnect01lowerA = new Cylinder(redArrowMat, 1, 6, _lobeConnectorSegs, 1);
			co2_lobeConnect01lowerA.x = 25;
			co2_lobeConnect01lowerA.z = -50;
			co2_lobeConnect01lowerA.rotationZ = 90;
			co2_lobeConnect01lowerB = new Cylinder(redArrowMat, 1, 6, _lobeConnectorSegs, 1);
			co2_lobeConnect01lowerB.x = 15;
			co2_lobeConnect01lowerB.z = -50;
			co2_lobeConnect01lowerB.rotationZ = 90;
			co2_lobeConnect01lowerC = new Cylinder(redArrowMat, 1, 6, _lobeConnectorSegs, 1);
			co2_lobeConnect01lowerC.x = 35;
			co2_lobeConnect01lowerC.z = -50;
			co2_lobeConnect01lowerC.rotationZ = 90;
			co2_lobeConnect02upperA = new Cylinder(blueArrowMat, 1, 6, _lobeConnectorSegs, 1);
			co2_lobeConnect02upperA.x = -25;
			co2_lobeConnect02upperA.y = 50;
			co2_lobeConnect02upperA.rotationZ = 90;
			co2_lobeConnect02upperB = new Cylinder(blueArrowMat, 1, 6, _lobeConnectorSegs, 1);
			co2_lobeConnect02upperB.x = -15;
			co2_lobeConnect02upperB.y = 50;
			co2_lobeConnect02upperB.rotationZ = 90;
			co2_lobeConnect02upperC = new Cylinder(blueArrowMat, 1, 6, _lobeConnectorSegs, 1);
			co2_lobeConnect02upperC.x = -35;
			co2_lobeConnect02upperC.y = 50;
			co2_lobeConnect02upperC.rotationZ = 90;
			co2_lobeConnect02lowerA = new Cylinder(blueArrowMat, 1, 6, _lobeConnectorSegs, 1);
			co2_lobeConnect02lowerA.x = -25;
			co2_lobeConnect02lowerA.y = -50;
			co2_lobeConnect02lowerA.rotationZ = 90;
			co2_lobeConnect02lowerB = new Cylinder(blueArrowMat, 1, 6, _lobeConnectorSegs, 1);
			co2_lobeConnect02lowerB.x = -15;
			co2_lobeConnect02lowerB.y = -50;
			co2_lobeConnect02lowerB.rotationZ = 90;
			co2_lobeConnect02lowerC = new Cylinder(blueArrowMat, 1, 6, _lobeConnectorSegs, 1);
			co2_lobeConnect02lowerC.x = -35;
			co2_lobeConnect02lowerC.y = -50;
			co2_lobeConnect02lowerC.rotationZ = 90;
			co2_carbon01.visible = false;
			co2_oxygen01.visible = false;
			co2_oxygen02.visible = false;
			co2_electron01a.visible = false;
			co2_electron01b.visible = false;
			co2_electron02a.visible = false;
			co2_electron02b.visible = false;
			co2_electron03a.visible = false;
			co2_electron03b.visible = false;
			co2_electron04a.visible = false;
			co2_electron04b.visible = false;
			co2_bond01.visible = false;
			co2_bond02.visible = false;
			co2_bond03.visible = false;
			co2_bond04.visible = false;
			co2_bond05.visible = false;
			co2_bond06.visible = false;
			co2_lobe01upper.visible = false;
			co2_lobe01lower.visible = false;
			co2_lobe02upper.visible = false;
			co2_lobe02lower.visible = false;
			co2_lobe03upper.visible = false;
			co2_lobe03lower.visible = false;
			co2_lobe04upper.visible = false;
			co2_lobe04lower.visible = false;
			co2_lobeConnect01upperA.visible = false;
			co2_lobeConnect01lowerA.visible = false;
			co2_lobeConnect01upperB.visible = false;
			co2_lobeConnect01lowerB.visible = false;
			co2_lobeConnect01upperC.visible = false;
			co2_lobeConnect01lowerC.visible = false;
			co2_lobeConnect02upperA.visible = false;
			co2_lobeConnect02lowerA.visible = false;
			co2_lobeConnect02upperB.visible = false;
			co2_lobeConnect02lowerB.visible = false;
			co2_lobeConnect02upperC.visible = false;
			co2_lobeConnect02lowerC.visible = false;
			
			c2h4_carbon01 = new Sphere(carbonMat, 12, _sphereSegs01, _sphereSegs02);
			c2h4_carbon01.rotationX = 90;
            c2h4_carbon01.x = -25;
            c2h4_carbon02 = new Sphere(carbonMat, 12, _sphereSegs01, _sphereSegs02);
            c2h4_carbon02.rotationX = 90;
            c2h4_carbon02.x = 25;
            c2h4_hydrogen01 = new Sphere(hydrogenMat, 12, _sphereSegs01, _sphereSegs02);
            c2h4_hydrogen01.rotationX = 90;
            c2h4_hydrogen01.x = -50;
            c2h4_hydrogen01.y = -43.3;
            c2h4_hydrogen02 = new Sphere(hydrogenMat, 12, _sphereSegs01, _sphereSegs02);
            c2h4_hydrogen02.rotationX = 90;
            c2h4_hydrogen02.x = -50;
            c2h4_hydrogen02.y = 43.3;
            c2h4_hydrogen03 = new Sphere(hydrogenMat, 12, _sphereSegs01, _sphereSegs02);
            c2h4_hydrogen03.rotationX = 90;
            c2h4_hydrogen03.x = 50;
            c2h4_hydrogen03.y = -43.3;
            c2h4_hydrogen04 = new Sphere(hydrogenMat, 12, _sphereSegs01, _sphereSegs02);
            c2h4_hydrogen04.rotationX = 90;
            c2h4_hydrogen04.x = 50;
            c2h4_hydrogen04.y = 43.3;
            c2h4_bond01 = new Cylinder(bondMat, 2.5, 25.5, 6, 1);
            c2h4_bond01.x = -37.5;
            c2h4_bond01.y = 21.7;
            c2h4_bond01.rotationX = 90;
            c2h4_bond01.rotationY = 90;            
            c2h4_bond01.rotationZ = -60;
            c2h4_bond02 = new Cylinder(bondMat, 2.5, 25.5, 6, 1);
            c2h4_bond02.x = -37.5;
            c2h4_bond02.y = -21.7;
            c2h4_bond02.rotationX = -90;
            c2h4_bond02.rotationY = 90;
            c2h4_bond02.rotationZ = -120;
            c2h4_bond03 = new Cylinder(bondMat, 2.5, 25.5, 6, 1);
            c2h4_bond03.x = 0;
            c2h4_bond03.rotationZ = 90;
            c2h4_bond04 = new Cylinder(bondMat, 2.5, 25.5, 6, 1);
            c2h4_bond04.x = 37.5;
            c2h4_bond04.y = -21.7;
            c2h4_bond04.rotationX = 90;
            c2h4_bond04.rotationY = 90;
            c2h4_bond04.rotationZ = -60;
            c2h4_bond05 = new Cylinder(bondMat, 2.5, 25.5, 6, 1);
            c2h4_bond05.x = 37.5;
            c2h4_bond05.y = 21.7;
            c2h4_bond05.rotationX = -90;
            c2h4_bond05.rotationY = 90;
            c2h4_bond05.rotationZ = -120;
            c2h4_lobe01upper = new DAE();
            c2h4_lobe01upper.load("../resources/assets/lobe.DAE", redLobeMat);
            c2h4_lobe01upper.scale = 0.85;
            c2h4_lobe01upper.rotationX = 90;
            c2h4_lobe01upper.z = 32;
            c2h4_lobe01upper.x = -25;
            c2h4_lobe01lower = new DAE();
            c2h4_lobe01lower.load("../resources/assets/lobe.DAE", redLobeMat);
            c2h4_lobe01lower.scale = 0.85;
            c2h4_lobe01lower.rotationX = 270;
            c2h4_lobe01lower.z = -32;
            c2h4_lobe01lower.x = -25;
            c2h4_lobe02upper = new DAE();
            c2h4_lobe02upper.load("../resources/assets/lobe.DAE", redLobeMat);
            c2h4_lobe02upper.scale = 0.85;
            c2h4_lobe02upper.rotationX = 90;
            c2h4_lobe02upper.z = 32;
            c2h4_lobe02upper.x = 25;
            c2h4_lobe02lower = new DAE();
            c2h4_lobe02lower.load("../resources/assets/lobe.DAE", redLobeMat);
            c2h4_lobe02lower.scale = 0.85;
            c2h4_lobe02lower.rotationX = 270;
            c2h4_lobe02lower.z = -32;
            c2h4_lobe02lower.x = 25;
            c2h4_lobeConnect01upperA = new Cylinder(redArrowMat, 1, 6, _lobeConnectorSegs, 1);
			c2h4_lobeConnect01upperA.x = 0;
			c2h4_lobeConnect01upperA.z = 50;
			c2h4_lobeConnect01upperA.rotationZ = 90;
			c2h4_lobeConnect01upperB = new Cylinder(redArrowMat, 1, 6, _lobeConnectorSegs, 1);
			c2h4_lobeConnect01upperB.x = -10;
			c2h4_lobeConnect01upperB.z = 50;
			c2h4_lobeConnect01upperB.rotationZ = 90;
			c2h4_lobeConnect01upperC = new Cylinder(redArrowMat, 1, 6, _lobeConnectorSegs, 1);
			c2h4_lobeConnect01upperC.x = 10;
			c2h4_lobeConnect01upperC.z = 50;
			c2h4_lobeConnect01upperC.rotationZ = 90;
			c2h4_lobeConnect01lowerA = new Cylinder(redArrowMat, 1, 6, _lobeConnectorSegs, 1);
			c2h4_lobeConnect01lowerA.x = 0;
			c2h4_lobeConnect01lowerA.z = -50;
			c2h4_lobeConnect01lowerA.rotationZ = 90;
			c2h4_lobeConnect01lowerB = new Cylinder(redArrowMat, 1, 6, _lobeConnectorSegs, 1);
			c2h4_lobeConnect01lowerB.x = -10;
			c2h4_lobeConnect01lowerB.z = -50;
			c2h4_lobeConnect01lowerB.rotationZ = 90;
			c2h4_lobeConnect01lowerC = new Cylinder(redArrowMat, 1, 6, _lobeConnectorSegs, 1);
			c2h4_lobeConnect01lowerC.x = 10;
			c2h4_lobeConnect01lowerC.z = -50;
			c2h4_lobeConnect01lowerC.rotationZ = 90;
            c2h4_carbon01.visible = false;
            c2h4_carbon02.visible = false;
            c2h4_hydrogen01.visible = false;
            c2h4_hydrogen02.visible = false;
            c2h4_hydrogen03.visible = false;
            c2h4_hydrogen04.visible = false;
            c2h4_bond01.visible = false;
            c2h4_bond02.visible = false;
            c2h4_bond03.visible = false;
            c2h4_bond04.visible = false;
            c2h4_bond05.visible = false;
            c2h4_lobe01upper.visible = false;
            c2h4_lobe01lower.visible = false;
            c2h4_lobe02upper.visible = false;
            c2h4_lobe02lower.visible = false;
            c2h4_lobeConnect01upperA.visible = false;
            c2h4_lobeConnect01lowerA.visible = false;
            c2h4_lobeConnect01upperB.visible = false;
            c2h4_lobeConnect01lowerB.visible = false;
            c2h4_lobeConnect01upperC.visible = false;
            c2h4_lobeConnect01lowerC.visible = false;
            
            ch3nh2_carbon01 = new Sphere(carbonMat, 12, _sphereSegs01, _sphereSegs02);
            ch3nh2_carbon01.rotationX = 90;
            ch3nh2_carbon01.rotationZ = 90;
            ch3nh2_nitrogen01 = new Sphere(nitrogenMat, 12, _sphereSegs01, _sphereSegs02);
            ch3nh2_nitrogen01.rotationX = 90;
            ch3nh2_nitrogen01.rotationZ = 90;
            ch3nh2_hydrogen01 = new Sphere(hydrogenMat, 12, _sphereSegs01, _sphereSegs02);
            ch3nh2_hydrogen01.z = 47;
            ch3nh2_hydrogen01.y = -17;
            ch3nh2_hydrogen01.rotationX = 90;
            ch3nh2_hydrogen01.rotationZ = 90;
            ch3nh2_hydrogen02 = new Sphere(hydrogenMat, 12, _sphereSegs01, _sphereSegs02);
            ch3nh2_hydrogen02.z = -23.5;
            ch3nh2_hydrogen02.y = -17;
            ch3nh2_hydrogen02.x = 40.7;
            ch3nh2_hydrogen02.rotationX = 90;
            ch3nh2_hydrogen02.rotationZ = 90;
            ch3nh2_hydrogen03 = new Sphere(hydrogenMat, 12, _sphereSegs01, _sphereSegs02);
            ch3nh2_hydrogen03.z = -23.5;
            ch3nh2_hydrogen03.y = -17;
            ch3nh2_hydrogen03.x = -40.7;
            ch3nh2_hydrogen03.rotationX = 90;
            ch3nh2_hydrogen03.rotationZ = 90;
            ch3nh2_hydrogen04 = new Sphere(hydrogenMat, 12, _sphereSegs01, _sphereSegs02);
            ch3nh2_hydrogen04.z = 23.5;
            ch3nh2_hydrogen04.y = 17;
            ch3nh2_hydrogen04.x = -40.7;
            ch3nh2_hydrogen04.rotationX = 90;
            ch3nh2_hydrogen04.rotationZ = 90;
            ch3nh2_hydrogen05 = new Sphere(hydrogenMat, 12, _sphereSegs01, _sphereSegs02);
            ch3nh2_hydrogen05.z = 23.5;
            ch3nh2_hydrogen05.y = 17;
            ch3nh2_hydrogen05.x = 40.7;
            ch3nh2_hydrogen05.rotationX = 90;
            ch3nh2_hydrogen05.rotationZ = 90;
            ch3nh2_electron01a = new Sphere(electronMat, 3.2, _electronSegs01, _electronSegs02);
			ch3nh2_electron01a.x = 5.5;
			ch3nh2_electron01b = new Sphere(electronMat, 3.2, _electronSegs01, _electronSegs02);
			ch3nh2_electron01b.x = -5.5;
            ch3nh2_bond01 = new Cylinder(bondMat, 2.5, 25.5, 6, 1);
            ch3nh2_bond02 = new Cylinder(bondMat, 2.5, 25.5, 6, 1);
            ch3nh2_bond02.z = 23.5;
            ch3nh2_bond02.y = -8.5;
            ch3nh2_bond02.rotationX = -70;
            ch3nh2_bond03 = new Cylinder(bondMat, 2.5, 25.5, 6, 1);
            ch3nh2_bond03.z = -11.5;
            ch3nh2_bond03.y = -8.5;
            ch3nh2_bond03.x = -20.5;
            ch3nh2_bond03.rotationX = 70;
            ch3nh2_bond03.rotationY = 60;
			ch3nh2_bond04 = new Cylinder(bondMat, 2.5, 25.5, 6, 1);
            ch3nh2_bond04.z = -11.5;
            ch3nh2_bond04.y = -8.5;
            ch3nh2_bond04.x = 20.5;
            ch3nh2_bond04.rotationX = 70;
            ch3nh2_bond04.rotationY = -60;
            ch3nh2_bond05 = new Cylinder(bondMat, 2.5, 25.5, 6, 1);
            ch3nh2_bond05.z = -23.5;
            ch3nh2_bond05.y = 8.5;
            ch3nh2_bond05.rotationX = -70;
            ch3nh2_bond06 = new Cylinder(bondMat, 2.5, 25.5, 6, 1);
            ch3nh2_bond06.z = 11.5;
            ch3nh2_bond06.y = 8.5;
            ch3nh2_bond06.x = -20.5;
            ch3nh2_bond06.rotationX = 70;
            ch3nh2_bond06.rotationY = -60;
            ch3nh2_bond07 = new Cylinder(bondMat, 2.5, 25.5, 6, 1);
            ch3nh2_bond07.z = 11.5;
            ch3nh2_bond07.y = 8.5;
            ch3nh2_bond07.x = 20.5;
            ch3nh2_bond07.rotationX = 70;
            ch3nh2_bond07.rotationY = 60;
            ch3nh2_carbon01.visible = false;
            ch3nh2_nitrogen01.visible = false;
            ch3nh2_hydrogen01.visible = false;
            ch3nh2_hydrogen02.visible = false;
            ch3nh2_hydrogen03.visible = false;
            ch3nh2_hydrogen04.visible = false;
            ch3nh2_hydrogen05.visible = false;
            ch3nh2_electron01a.visible = false;
            ch3nh2_electron01b.visible = false;
            ch3nh2_bond01.visible = false;
            ch3nh2_bond02.visible = false;
            ch3nh2_bond03.visible = false;
            ch3nh2_bond04.visible = false;
            ch3nh2_bond05.visible = false;
            ch3nh2_bond06.visible = false;
            ch3nh2_bond07.visible = false;
            
            of2_oxygen01 = new Sphere(oxygenMat, 12, _sphereSegs01, _sphereSegs02);
            of2_oxygen01.rotationX = 90;
            of2_fluoride01 = new Sphere(fluorideMat, 12, _sphereSegs01, _sphereSegs02);
            of2_fluoride01.rotationX = 90;
            of2_fluoride01.x = -33.2;
            of2_fluoride01.y = -33.2;
            of2_fluoride01.z = -17.1;
            of2_fluoride02 = new Sphere(fluorideMat, 12, _sphereSegs01, _sphereSegs02);
            of2_fluoride02.rotationX = 90;
            of2_fluoride02.x = -33.2;
            of2_fluoride02.y = 33.2;
            of2_fluoride02.z = -17.1;
            of2_bond01 = new Cylinder(bondMat, 2.5, 22.95, 6, 1);
            of2_bond01.x = -4.12;
            of2_bond01.y = 0;
            of2_bond01.z = 23.4;
            of2_bond01.rotationX = 80;
            of2_bond01.rotationY = 0;
            of2_bond01.rotationZ = 90;
            of2_bond02 = new Cylinder(bondMat, 2.5, 22.95, 6, 1);
            of2_bond02.x = 20.6;
            of2_bond02.y = 0;
            of2_bond02.z = -11.9;
            of2_bond02.rotationX = 30;
            of2_bond02.rotationY = 0;
            of2_bond02.rotationZ = 90;
            of2_bond03 = new Cylinder(bondMat, 2.5, 25.5, 6, 1);
            of2_bond03.x = -16.6;
            of2_bond03.y = -16.6;
            of2_bond03.z = -8.6;
            of2_bond03.rotationX = 20;
            of2_bond03.rotationY = 0;
            of2_bond03.rotationZ = -45;
            of2_bond04 = new Cylinder(bondMat, 2.5, 25.5, 6, 1);
            of2_bond04.x = -16.6;
            of2_bond04.y = 16.6;
            of2_bond04.z = -8.6;
            of2_bond04.rotationX = 20;
            of2_bond04.rotationY = 0;
            of2_bond04.rotationZ = -135;
            of2_electron01a = new Sphere(electronMat, 3.2, _electronSegs01, _electronSegs02);
			of2_electron01a.x = 5.5;
			of2_electron01a.y = 17;
			of2_electron01b = new Sphere(electronMat, 3.2, _electronSegs01, _electronSegs02);
			of2_electron01b.x = -5.5;
			of2_electron01b.y = 17;
			of2_electron02a = new Sphere(electronMat, 3.2, _electronSegs01, _electronSegs02);
			of2_electron02a.x = 5.5;
			of2_electron02a.y = -17;
			of2_electron02b = new Sphere(electronMat, 3.2, _electronSegs01, _electronSegs02);
			of2_electron02b.x = -5.5;
			of2_electron02b.y = -17;
			of2_arrowDAE01 = new DAE();
            of2_arrowDAE01.load("../resources/assets/of2_arrow01.DAE", redArrow);
            of2_arrowDAE01.rotationX = 90;
            of2_arrowDAE02 = new DAE();
            of2_arrowDAE02.load("../resources/assets/of2_arrow02.DAE", yellowArrow);
            of2_arrowDAE02.rotationX = 90;
			of2_oxygen01.visible = false;
			of2_fluoride01.visible = false;
			of2_fluoride02.visible = false;
			of2_bond01.visible = false;
			of2_bond02.visible = false;
			of2_bond03.visible = false;
			of2_bond04.visible = false;
			of2_electron01a.visible = false;
			of2_electron01b.visible = false;
			of2_electron02a.visible = false;
			of2_electron02b.visible = false;
			of2_arrowDAE01.visible = false;
			of2_arrowDAE02.visible = false;
			
			sp_carbon01 = new Sphere(carbonMat, 12, _sphereSegs01, _sphereSegs02);
			sp_carbon01.rotationX = 90;
			sp_bond01 = new Cylinder(bondMat, 2.5, 25.5, 6, 1);
			sp_bond01.x = -25;
			sp_bond01.rotationZ = 90;
			sp_bond02 = new Cylinder(bondMat, 2.5, 25.5, 6, 1);
			sp_bond02.x = 25;
			sp_bond02.rotationZ = 90;
			sp_electron01 = new Sphere(electronMat, 3.2, _electronSegs01, _electronSegs02);
			sp_electron01.x = -42;
			sp_electron02 = new Sphere(electronMat, 3.2, _electronSegs01, _electronSegs02);
			sp_electron02.x = 42;
			sp_lobe01upper = new DAE();
            sp_lobe01upper.load("../resources/assets/lobe.DAE", redLobeMat);
            sp_lobe01upper.scale = 0.85;
            sp_lobe01upper.rotationX = 90;
            sp_lobe01upper.z = 32;
            sp_lobe01lower = new DAE();
            sp_lobe01lower.load("../resources/assets/lobe.DAE", redLobeMat);
            sp_lobe01lower.scale = 0.85;
            sp_lobe01lower.rotationX = 270;
            sp_lobe01lower.z = -32;
            sp_lobe02upper = new DAE();
			sp_lobe02upper.load("../resources/assets/lobe.DAE", blueLobeMat);
			sp_lobe02upper.scale = 0.85;
			sp_lobe02upper.y = 32;
			sp_lobe02lower = new DAE();
			sp_lobe02lower.load("../resources/assets/lobe.DAE", blueLobeMat);
			sp_lobe02lower.scale = 0.85;
			sp_lobe02lower.rotationX = 180;
			sp_lobe02lower.y = -32;
			sp2_carbon01 = new Sphere(carbonMat, 12, _sphereSegs01, _sphereSegs02);
			sp2_carbon01.rotationX = 90;
			sp2_bond01 = new Cylinder(bondMat, 2.5, 25.5, 6, 1);
			sp2_bond01.x = 25;
			sp2_bond01.rotationZ = 90;
			sp2_bond02 = new Cylinder(bondMat, 2.5, 25.5, 6, 1);
			sp2_bond02.x = -12.5;
			sp2_bond02.y = -21.7;
			sp2_bond02.rotationX = 0;
			sp2_bond02.rotationY = 0;
			sp2_bond02.rotationZ = 150;
			sp2_bond03 = new Cylinder(bondMat, 2.5, 25.5, 6, 1);
			sp2_bond03.x = -12.5;
			sp2_bond03.y = 21.7;
			sp2_bond03.rotationX = 0;
			sp2_bond03.rotationY = 0;
			sp2_bond03.rotationZ = 210;
			sp2_electron01 = new Sphere(electronMat, 3.2, _electronSegs01, _electronSegs02);
			sp2_electron01.x = 42;
			sp2_electron02 = new Sphere(electronMat, 3.2, _electronSegs01, _electronSegs02);
			sp2_electron02.y = 17;
			sp2_electron03 = new Sphere(electronMat, 3.2, _electronSegs01, _electronSegs02);
			sp2_electron03.y = -17;			
			sp2_lobe01upper = new DAE();
            sp2_lobe01upper.load("../resources/assets/lobe.DAE", redLobeMat);
            sp2_lobe01upper.scale = 0.85;
            sp2_lobe01upper.rotationX = 90;
            sp2_lobe01upper.z = 32;
            sp2_lobe01lower = new DAE();
            sp2_lobe01lower.load("../resources/assets/lobe.DAE", redLobeMat);
            sp2_lobe01lower.scale = 0.85;
            sp2_lobe01lower.rotationX = 270;
            sp2_lobe01lower.z = -32;
			sp3_carbon01 = new Sphere(carbonMat, 12, _sphereSegs01, _sphereSegs02);
			sp3_carbon01.rotationX = 90;
			sp3_bond01 = new Cylinder(bondMat, 2.5, 25.5, 6, 1);
            sp3_bond01.z = 25;
            sp3_bond01.rotationX = 90;
            sp3_bond02 = new Cylinder(bondMat, 2.5, 25.5, 6, 1);
            sp3_bond02.z = -5.5;
            sp3_bond02.x = 23.5;
            sp3_bond02.rotationZ = 90;
            sp3_bond02.rotationX = 20;
            sp3_bond03 = new Cylinder(bondMat, 2.5, 25.5, 6, 1);
            sp3_bond03.z = -5.5;
            sp3_bond03.x = -12.5;
            sp3_bond03.y = -21.5;
            sp3_bond03.rotationZ = -30;
            sp3_bond03.rotationX = 20;
            sp3_bond04 = new Cylinder(bondMat, 2.5, 25.5, 6, 1);
            sp3_bond04.z = -5.5;
            sp3_bond04.x = -12.5;
            sp3_bond04.y = 21.5;
            sp3_bond04.rotationZ = -150;
            sp3_bond04.rotationX = 20;
            sp3_electron01 = new Sphere(electronMat, 3.2, _electronSegs01, _electronSegs02);
			sp3_electron01.z = 42;
			sp3_electron02 = new Sphere(electronMat, 3.2, _electronSegs01, _electronSegs02);
			sp3_electron02.y = -17;
			sp3_electron03 = new Sphere(electronMat, 3.2, _electronSegs01, _electronSegs02);
			sp3_electron03.y = -17;
			sp3_electron04 = new Sphere(electronMat, 3.2, _electronSegs01, _electronSegs02);
			sp3_electron04.y = -17;
			sp_carbon01.visible = false;
			sp_bond01.visible = false;
			sp_bond02.visible = false;
			sp_electron01.visible = false;
			sp_electron02.visible = false;
			sp_lobe01upper.visible = false;
			sp_lobe01lower.visible = false;
			sp_lobe02upper.visible = false;
			sp_lobe02lower.visible = false;
			sp2_carbon01.visible = false;
			sp2_bond01.visible = false;
			sp2_bond02.visible = false;
			sp2_bond03.visible = false;
			sp2_electron01.visible = false;
			sp2_electron02.visible = false;
			sp2_electron03.visible = false;
			sp2_lobe01upper.visible = false;
			sp2_lobe01lower.visible = false;
			sp3_carbon01.visible = false;
			sp3_bond01.visible = false;
			sp3_bond02.visible = false;
			sp3_bond03.visible = false;
			sp3_bond04.visible = false;
			sp3_electron01.visible = false;
			sp3_electron02.visible = false;
			sp3_electron03.visible = false;
			sp3_electron04.visible = false;
			
		}

		public function addMarker (marker:FLARMarker) :void {
			
			// store marker
			var markerList:Vector.<FLARMarker> = this.markersByPatternId[marker.patternId];
			markerList.push(marker);
			var container:DisplayObject3D = new DisplayObject3D();
			if(marker.patternId == 0)	{
				m_00 = true;
				var _ch4:DisplayObject3D = new DisplayObject3D();
				_ch4.z = 50;
				_ch4.rotationZ = 90;
				ch4_carbon01.visible = true;
	            ch4_hydrogen01.visible = true;
	            ch4_hydrogen02.visible = true;
	            ch4_hydrogen03.visible = true;
	            ch4_hydrogen04.visible = true;
	            ch4_bond01.visible = true;
	            ch4_bond02.visible = true;
	            ch4_bond03.visible = true;
	            ch4_bond04.visible = true;
	            //ch4_shadow.visible = true;
				
				_ch4.addChild(ch4_carbon01);
				_ch4.addChild(ch4_hydrogen01);
				_ch4.addChild(ch4_hydrogen02);
				_ch4.addChild(ch4_hydrogen03);
				_ch4.addChild(ch4_hydrogen04);
				_ch4.addChild(ch4_bond01);
				_ch4.addChild(ch4_bond02);
				_ch4.addChild(ch4_bond03);
				_ch4.addChild(ch4_bond04);
				//_ch4.addChild(ch4_shadow);
				container.addChild(_ch4);
				this.scene3D.addChild(container);
				
				// associate container with corresponding marker
				this.containersByMarker[marker] = container;
			}
			if(marker.patternId == 1)	{
				m_01 = true;
				var _nh3:DisplayObject3D = new DisplayObject3D();
				_nh3.z = 50;
				_nh3.rotationZ = 90;
				nh3_nitrogen01.visible = true;
	            nh3_hydrogen01.visible = true;
	            nh3_hydrogen02.visible = true;
	            nh3_hydrogen03.visible = true;
	            nh3_bond01.visible = true;
	            nh3_bond02.visible = true;
	            nh3_bond03.visible = true;
	            nh3_bond04.visible = true;
	            nh3_electron01a.visible = true;
	            nh3_electron01b.visible = true;
				
				_nh3.addChild(nh3_nitrogen01);
				_nh3.addChild(nh3_hydrogen01);
				_nh3.addChild(nh3_hydrogen02);
				_nh3.addChild(nh3_hydrogen03);
				_nh3.addChild(nh3_bond01);
				_nh3.addChild(nh3_bond02);
				_nh3.addChild(nh3_bond03);
				_nh3.addChild(nh3_bond04);
				_nh3.addChild(nh3_electron01a);
				_nh3.addChild(nh3_electron01b);
				container.addChild(_nh3);
				this.scene3D.addChild(container);
				
				// associate container with corresponding marker
				this.containersByMarker[marker] = container;
			}
			if(marker.patternId == 2)	{
				m_02 = true;
				var _c3h6:DisplayObject3D = new DisplayObject3D();
				_c3h6.z = 50;
				_c3h6.rotationZ = 270;
				
				c3h6_carbon01.visible = true;
				c3h6_carbon02.visible = true;
				c3h6_carbon03.visible = true;
				c3h6_hydrogen01.visible = true;
				c3h6_hydrogen02.visible = true;
				c3h6_hydrogen03.visible = true;
				c3h6_hydrogen04.visible = true;
				c3h6_hydrogen05.visible = true;
				c3h6_hydrogen06.visible = true;
				c3h6_lobe01upper.visible = true;
				c3h6_lobe01lower.visible = true;
				c3h6_lobe02upper.visible = true;
				c3h6_lobe02lower.visible = true;
				c3h6_bond01.visible = true;
				c3h6_bond02.visible = true;
				c3h6_bond03.visible = true;
				c3h6_bond04.visible = true;
				c3h6_bond05.visible = true;
				c3h6_bond06.visible = true;
				c3h6_bond07.visible = true;
				c3h6_bond08.visible = true;
				c3h6_lobeConnect01upperA.visible = true;
				c3h6_lobeConnect01lowerA.visible = true;
				c3h6_lobeConnect01upperB.visible = true;
				c3h6_lobeConnect01lowerB.visible = true;
				c3h6_lobeConnect01upperC.visible = true;
				c3h6_lobeConnect01lowerC.visible = true;
				
				_c3h6.addChild(c3h6_carbon01);
				_c3h6.addChild(c3h6_carbon02);
				_c3h6.addChild(c3h6_carbon03);
				_c3h6.addChild(c3h6_hydrogen01);
				_c3h6.addChild(c3h6_hydrogen02);
				_c3h6.addChild(c3h6_hydrogen03);
				_c3h6.addChild(c3h6_hydrogen04);
				_c3h6.addChild(c3h6_hydrogen05);
				_c3h6.addChild(c3h6_hydrogen06);
				_c3h6.addChild(c3h6_lobe01upper);
				_c3h6.addChild(c3h6_lobe01lower);
				_c3h6.addChild(c3h6_lobe02upper);
				_c3h6.addChild(c3h6_lobe02lower);
				_c3h6.addChild(c3h6_bond01);
				_c3h6.addChild(c3h6_bond02);
				_c3h6.addChild(c3h6_bond03);
				_c3h6.addChild(c3h6_bond04);
				_c3h6.addChild(c3h6_bond05);
				_c3h6.addChild(c3h6_bond06);
				_c3h6.addChild(c3h6_bond07);
				_c3h6.addChild(c3h6_bond08);
				_c3h6.addChild(c3h6_lobeConnect01upperA);
				_c3h6.addChild(c3h6_lobeConnect01lowerA);
				_c3h6.addChild(c3h6_lobeConnect01upperB);
				_c3h6.addChild(c3h6_lobeConnect01lowerB);
				_c3h6.addChild(c3h6_lobeConnect01upperC);
				_c3h6.addChild(c3h6_lobeConnect01lowerC);
				container.addChild(_c3h6);
				this.scene3D.addChild(container);
				
				// associate container with corresponding marker
				this.containersByMarker[marker] = container;
			}
			if(marker.patternId == 3)	{
				m_03 = true;
				var _c2h2:DisplayObject3D = new DisplayObject3D();
				_c2h2.z = 50;
				_c2h2.rotationZ = 270;
				c2h2_carbon01.visible = true;
	            c2h2_carbon02.visible = true;
	            c2h2_hydrogen01.visible = true;
	            c2h2_hydrogen02.visible = true;
	            c2h2_bond01.visible = true;
	            c2h2_bond02.visible = true;
	            c2h2_bond03.visible = true;
	            c2h2_lobe01upper.visible = true;
	            c2h2_lobe01lower.visible = true;
	            c2h2_lobe02upper.visible = true;
	            c2h2_lobe02lower.visible = true;
	            c2h2_lobe03upper.visible = true;
	            c2h2_lobe03lower.visible = true;
	            c2h2_lobe04upper.visible = true;
	            c2h2_lobe04lower.visible = true;
	            c2h2_lobeConnect01upperA.visible = true;
	            c2h2_lobeConnect01upperB.visible = true;
	            c2h2_lobeConnect01upperC.visible = true;
	            c2h2_lobeConnect01lowerA.visible = true;
	            c2h2_lobeConnect01lowerB.visible = true;
	            c2h2_lobeConnect01lowerC.visible = true;
	            c2h2_lobeConnect02upperA.visible = true;
	            c2h2_lobeConnect02upperB.visible = true;
	            c2h2_lobeConnect02upperC.visible = true;
	            c2h2_lobeConnect02lowerA.visible = true;
	            c2h2_lobeConnect02lowerB.visible = true;
	            c2h2_lobeConnect02lowerC.visible = true;
	            _c2h2.addChild(c2h2_carbon01);
	            _c2h2.addChild(c2h2_carbon02);
	            _c2h2.addChild(c2h2_hydrogen01);
	            _c2h2.addChild(c2h2_hydrogen02);
	            _c2h2.addChild(c2h2_bond01);
	            _c2h2.addChild(c2h2_bond02);
	            _c2h2.addChild(c2h2_bond03);
	            _c2h2.addChild(c2h2_lobe01upper);
	            _c2h2.addChild(c2h2_lobe01lower);
	            _c2h2.addChild(c2h2_lobe02upper);
	            _c2h2.addChild(c2h2_lobe02lower);
	            _c2h2.addChild(c2h2_lobe03upper);
	            _c2h2.addChild(c2h2_lobe03lower);
	            _c2h2.addChild(c2h2_lobe04upper);
	            _c2h2.addChild(c2h2_lobe04lower);
	            _c2h2.addChild(c2h2_lobeConnect01upperA);
	            _c2h2.addChild(c2h2_lobeConnect01upperB);
	            _c2h2.addChild(c2h2_lobeConnect01upperC);
	            _c2h2.addChild(c2h2_lobeConnect01lowerA);
	            _c2h2.addChild(c2h2_lobeConnect01lowerB);
	            _c2h2.addChild(c2h2_lobeConnect01lowerC);
	            _c2h2.addChild(c2h2_lobeConnect02upperA);
	            _c2h2.addChild(c2h2_lobeConnect02upperB);
	            _c2h2.addChild(c2h2_lobeConnect02upperC);
	            _c2h2.addChild(c2h2_lobeConnect02lowerA);
	            _c2h2.addChild(c2h2_lobeConnect02lowerB);
	            _c2h2.addChild(c2h2_lobeConnect02lowerC);
	            container.addChild(_c2h2);
				this.scene3D.addChild(container);
				
				// associate container with corresponding marker
				this.containersByMarker[marker] = container;
			}
			if(marker.patternId == 4)	{
				m_04 = true;
				var _c2h6:DisplayObject3D = new DisplayObject3D();
				var _c2h6a:DisplayObject3D = new DisplayObject3D();
				var _c2h6b:DisplayObject3D = new DisplayObject3D();
				_c2h6a.y = -25;
				_c2h6b.y = 25;
				_c2h6.z = 50;
				c2h6_carbon01.visible = true;
				c2h6_carbon02.visible = true;
				c2h6_hydrogen01.visible = true;
				c2h6_hydrogen02.visible = true;
				c2h6_hydrogen03.visible = true;
				c2h6_hydrogen04.visible = true;
				c2h6_hydrogen05.visible = true;
				c2h6_hydrogen06.visible = true;
				c2h6_bond01.visible = true;
				c2h6_bond02.visible = true;
				c2h6_bond03.visible = true;
				c2h6_bond04.visible = true;
				c2h6_bond05.visible = true;
				c2h6_bond06.visible = true;
				c2h6_bond07.visible = true;
				_c2h6a.addChild(c2h6_carbon01);
				_c2h6a.addChild(c2h6_hydrogen01);
				_c2h6a.addChild(c2h6_hydrogen02);
				_c2h6a.addChild(c2h6_hydrogen03);
				_c2h6a.addChild(c2h6_bond02);
				_c2h6a.addChild(c2h6_bond03);
				_c2h6a.addChild(c2h6_bond04);
				_c2h6b.addChild(c2h6_carbon02);
				_c2h6b.addChild(c2h6_hydrogen04);
				_c2h6b.addChild(c2h6_hydrogen05);
				_c2h6b.addChild(c2h6_hydrogen06);
				_c2h6b.addChild(c2h6_bond05);
				_c2h6b.addChild(c2h6_bond06);
				_c2h6b.addChild(c2h6_bond07);
				_c2h6.addChild(c2h6_bond01);
				_c2h6.addChild(_c2h6a);
				_c2h6.addChild(_c2h6b);
				container.addChild(_c2h6);
				this.scene3D.addChild(container);
				
				// associate container with corresponding marker
				this.containersByMarker[marker] = container;
			}
			if(marker.patternId == 5)	{
				m_05 = true;
				var _ch3conh2:DisplayObject3D = new DisplayObject3D();
				var _ch3conh2_lonePair01:DisplayObject3D = new DisplayObject3D();
				var _ch3conh2_lonePair02:DisplayObject3D = new DisplayObject3D();
				var _ch3conh2_lonePair03:DisplayObject3D = new DisplayObject3D();
				_ch3conh2_lonePair01.x = -75;
				_ch3conh2_lonePair01.y = 43.3;
				_ch3conh2_lonePair01.rotationZ = 30;
				_ch3conh2_lonePair02.x = -75;
				_ch3conh2_lonePair02.y = -43.3;
				_ch3conh2_lonePair02.rotationZ = -30;
				_ch3conh2_lonePair03.x = -2.125;
				_ch3conh2_lonePair03.y = -77.7;
				_ch3conh2_lonePair03.z = -24.1;
				_ch3conh2_lonePair03.rotationX = -30.78;
				_ch3conh2_lonePair03.rotationY = 171;
				_ch3conh2_lonePair03.rotationZ = -43.24;
				_ch3conh2.z = 50;
				_ch3conh2.rotationZ = 270;
				ch3conh2_carbon01.visible = true;
	            ch3conh2_carbon02.visible = true;
	            ch3conh2_oxygen01.visible = true;
	            ch3conh2_hydrogen01.visible = true;
	            ch3conh2_hydrogen02.visible = true;
	            ch3conh2_hydrogen03.visible = true;
	            ch3conh2_hydrogen04.visible = true;
	            ch3conh2_hydrogen05.visible = true;
	            ch3conh2_nitrogen01.visible = true;
	            ch3conh2_electron01a.visible = true;
	            ch3conh2_electron01b.visible = true;
	            ch3conh2_electron02a.visible = true;
	            ch3conh2_electron02b.visible = true;
	            ch3conh2_electron03a.visible = true;
	            ch3conh2_electron03b.visible = true;
	            ch3conh2_bond01.visible = true;
	            ch3conh2_bond02.visible = true;
	            ch3conh2_bond03.visible = true;
	            ch3conh2_bond04.visible = true;
	            ch3conh2_bond05.visible = true;
	            ch3conh2_bond06.visible = true;
	            ch3conh2_bond07.visible = true;
	            ch3conh2_bond08.visible = true;
	            ch3conh2_bond09.visible = true;
	            ch3conh2_bond10.visible = true;
	            ch3conh2_bond11.visible = true;
	            ch3conh2_lobe01upper.visible = true;
	            ch3conh2_lobe01lower.visible = true;
	            ch3conh2_lobe02upper.visible = true;
	            ch3conh2_lobe02lower.visible = true;
		        ch3conh2_lobeConnect01upperA.visible = true;
	            ch3conh2_lobeConnect01upperB.visible = true;
	            ch3conh2_lobeConnect01upperC.visible = true;
	            ch3conh2_lobeConnect01lowerA.visible = true;
	            ch3conh2_lobeConnect01lowerB.visible = true;
	            ch3conh2_lobeConnect01lowerC.visible = true;
	            _ch3conh2_lonePair01.addChild(ch3conh2_electron01a);
	            _ch3conh2_lonePair01.addChild(ch3conh2_electron01b);
	            _ch3conh2_lonePair02.addChild(ch3conh2_electron02a);
	            _ch3conh2_lonePair02.addChild(ch3conh2_electron02b);
	            _ch3conh2_lonePair03.addChild(ch3conh2_electron03a);
	            _ch3conh2_lonePair03.addChild(ch3conh2_electron03b);
				_ch3conh2.addChild(ch3conh2_carbon01);
				_ch3conh2.addChild(ch3conh2_carbon02);
				_ch3conh2.addChild(ch3conh2_oxygen01);
				_ch3conh2.addChild(ch3conh2_hydrogen01);
				_ch3conh2.addChild(ch3conh2_hydrogen02);
				_ch3conh2.addChild(ch3conh2_hydrogen03);
				_ch3conh2.addChild(ch3conh2_hydrogen04);
				_ch3conh2.addChild(ch3conh2_hydrogen05);
				_ch3conh2.addChild(ch3conh2_nitrogen01);
				_ch3conh2.addChild(ch3conh2_bond01);
				_ch3conh2.addChild(ch3conh2_bond02);
				_ch3conh2.addChild(ch3conh2_bond03);
				_ch3conh2.addChild(ch3conh2_bond04);
				_ch3conh2.addChild(ch3conh2_bond05);
				_ch3conh2.addChild(ch3conh2_bond06);
				_ch3conh2.addChild(ch3conh2_bond07);
				_ch3conh2.addChild(ch3conh2_bond08);
				_ch3conh2.addChild(ch3conh2_bond09);
				_ch3conh2.addChild(ch3conh2_bond10);
				_ch3conh2.addChild(ch3conh2_bond11);
				_ch3conh2.addChild(ch3conh2_lobe01upper);
				_ch3conh2.addChild(ch3conh2_lobe01lower);
				_ch3conh2.addChild(ch3conh2_lobe02upper);
				_ch3conh2.addChild(ch3conh2_lobe02lower);
				_ch3conh2.addChild(_ch3conh2_lonePair01);
				_ch3conh2.addChild(_ch3conh2_lonePair02);
				_ch3conh2.addChild(_ch3conh2_lonePair03);
				_ch3conh2.addChild(ch3conh2_lobeConnect01upperA);
				_ch3conh2.addChild(ch3conh2_lobeConnect01lowerA);
				_ch3conh2.addChild(ch3conh2_lobeConnect01upperB);
				_ch3conh2.addChild(ch3conh2_lobeConnect01lowerB);
				_ch3conh2.addChild(ch3conh2_lobeConnect01upperC);
				_ch3conh2.addChild(ch3conh2_lobeConnect01lowerC);
				container.addChild(_ch3conh2);
				this.scene3D.addChild(container);
				
				// associate container with corresponding marker
				this.containersByMarker[marker] = container;
			}
			if(marker.patternId == 6)	{
				m_06 = true;
				var _co2:DisplayObject3D = new DisplayObject3D();
				var _co2_lonePair01:DisplayObject3D = new DisplayObject3D();
				var _co2_lonePair02:DisplayObject3D = new DisplayObject3D();
				var _co2_lonePair03:DisplayObject3D = new DisplayObject3D();
				var _co2_lonePair04:DisplayObject3D = new DisplayObject3D();
				_co2_lonePair01.x = -75;
				_co2_lonePair01.z = 43.3;
				_co2_lonePair01.rotationY = 150
				_co2_lonePair02.x = -75;
				_co2_lonePair02.z = -43.3;
				_co2_lonePair02.rotationY = -150
				_co2_lonePair03.x = 75;
				_co2_lonePair03.y = -43.3;
				_co2_lonePair03.rotationY = -180;
				_co2_lonePair03.rotationZ = -150;
				_co2_lonePair04.x = 75;
				_co2_lonePair04.y = 43.3;
				_co2_lonePair04.rotationY = -180;
				_co2_lonePair04.rotationZ = 150;
				_co2.z = 50;
				_co2.rotationZ = 90;
				co2_carbon01.visible = true;
				co2_oxygen01.visible = true;
				co2_oxygen02.visible = true;
				co2_electron01a.visible = true;
				co2_electron01b.visible = true;
				co2_electron02a.visible = true;
				co2_electron02b.visible = true;
				co2_electron03a.visible = true;
				co2_electron03b.visible = true;
				co2_electron04a.visible = true;
				co2_electron04b.visible = true;
				co2_bond01.visible = true;
				co2_bond02.visible = true;
				co2_bond03.visible = true;
				co2_bond04.visible = true;
				co2_bond05.visible = true;
				co2_bond06.visible = true;
				co2_lobe01upper.visible = true;
				co2_lobe01lower.visible = true;
				co2_lobe02upper.visible = true;
				co2_lobe02lower.visible = true;
				co2_lobe03upper.visible = true;
				co2_lobe03lower.visible = true;
				co2_lobe04upper.visible = true;
				co2_lobe04lower.visible = true;
				co2_lobeConnect01upperA.visible = true;
				co2_lobeConnect01lowerA.visible = true;
				co2_lobeConnect01upperB.visible = true;
				co2_lobeConnect01lowerB.visible = true;
				co2_lobeConnect01upperC.visible = true;
				co2_lobeConnect01lowerC.visible = true;
				co2_lobeConnect02upperA.visible = true;
				co2_lobeConnect02lowerA.visible = true;
				co2_lobeConnect02upperB.visible = true;
				co2_lobeConnect02lowerB.visible = true;
				co2_lobeConnect02upperC.visible = true;
				co2_lobeConnect02lowerC.visible = true;
				_co2_lonePair01.addChild(co2_electron01a);
				_co2_lonePair01.addChild(co2_electron01b);
				_co2_lonePair02.addChild(co2_electron02a);
				_co2_lonePair02.addChild(co2_electron02b);
				_co2_lonePair03.addChild(co2_electron03a);
				_co2_lonePair03.addChild(co2_electron03b);
				_co2_lonePair04.addChild(co2_electron04a);
				_co2_lonePair04.addChild(co2_electron04b);
				_co2.addChild(co2_carbon01);
				_co2.addChild(co2_oxygen01);
				_co2.addChild(co2_oxygen02);
				_co2.addChild(co2_bond01);
				_co2.addChild(co2_bond02);
				_co2.addChild(co2_bond03);
				_co2.addChild(co2_bond04);
				_co2.addChild(co2_bond05);
				_co2.addChild(co2_bond06);
				_co2.addChild(co2_lobe01upper);
				_co2.addChild(co2_lobe01lower);
				_co2.addChild(co2_lobe02upper);
				_co2.addChild(co2_lobe02lower);
				_co2.addChild(co2_lobe03upper);
				_co2.addChild(co2_lobe03lower);
				_co2.addChild(co2_lobe04upper);
				_co2.addChild(co2_lobe04lower);
				_co2.addChild(_co2_lonePair01);
				_co2.addChild(_co2_lonePair02);
				_co2.addChild(_co2_lonePair03);
				_co2.addChild(_co2_lonePair04);
				_co2.addChild(co2_lobeConnect01upperA);
				_co2.addChild(co2_lobeConnect01lowerA);
				_co2.addChild(co2_lobeConnect01upperB);
				_co2.addChild(co2_lobeConnect01lowerB);
				_co2.addChild(co2_lobeConnect01upperC);
				_co2.addChild(co2_lobeConnect01lowerC);
				_co2.addChild(co2_lobeConnect02upperA);
				_co2.addChild(co2_lobeConnect02lowerA);
				_co2.addChild(co2_lobeConnect02upperB);
				_co2.addChild(co2_lobeConnect02lowerB);
				_co2.addChild(co2_lobeConnect02upperC);
				_co2.addChild(co2_lobeConnect02lowerC);
				container.addChild(_co2);
				this.scene3D.addChild(container);
				
				// associate container with corresponding marker
				this.containersByMarker[marker] = container;
			}
			if(marker.patternId == 7)	{
				m_07 = true;
				var _c2h4:DisplayObject3D = new DisplayObject3D();
				_c2h4.z = 50;
				_c2h4.rotationZ = 90;
				c2h4_carbon01.visible = true;
	            c2h4_carbon02.visible = true;
	            c2h4_hydrogen01.visible = true;
	            c2h4_hydrogen02.visible = true;
	            c2h4_hydrogen03.visible = true;
	            c2h4_hydrogen04.visible = true;
	            c2h4_bond01.visible = true;
	            c2h4_bond02.visible = true;
	            c2h4_bond03.visible = true;
	            c2h4_bond04.visible = true;
	            c2h4_bond05.visible = true;
	            c2h4_lobe01upper.visible = true;
	            c2h4_lobe01lower.visible = true;
	            c2h4_lobe02upper.visible = true;
	            c2h4_lobe02lower.visible = true;
	            c2h4_lobeConnect01upperA.visible = true;
	            c2h4_lobeConnect01lowerA.visible = true;
	            c2h4_lobeConnect01upperB.visible = true;
	            c2h4_lobeConnect01lowerB.visible = true;
	            c2h4_lobeConnect01upperC.visible = true;
	            c2h4_lobeConnect01lowerC.visible = true;
	            _c2h4.addChild(c2h4_carbon01);
	            _c2h4.addChild(c2h4_carbon02);
	            _c2h4.addChild(c2h4_hydrogen01);
	            _c2h4.addChild(c2h4_hydrogen02);
	            _c2h4.addChild(c2h4_hydrogen03);
	            _c2h4.addChild(c2h4_hydrogen04);
	            _c2h4.addChild(c2h4_bond01);
	            _c2h4.addChild(c2h4_bond02);
	            _c2h4.addChild(c2h4_bond03);
	            _c2h4.addChild(c2h4_bond04);
	            _c2h4.addChild(c2h4_bond05);
	            _c2h4.addChild(c2h4_lobe01upper);
	            _c2h4.addChild(c2h4_lobe01lower);
	            _c2h4.addChild(c2h4_lobe02upper);
	            _c2h4.addChild(c2h4_lobe02lower);
	            _c2h4.addChild(c2h4_lobeConnect01upperA);
	            _c2h4.addChild(c2h4_lobeConnect01lowerA);
	            _c2h4.addChild(c2h4_lobeConnect01upperB);
	            _c2h4.addChild(c2h4_lobeConnect01lowerB);
	            _c2h4.addChild(c2h4_lobeConnect01upperC);
	            _c2h4.addChild(c2h4_lobeConnect01lowerC);
				container.addChild(_c2h4);
				this.scene3D.addChild(container);
				
				// associate container with corresponding marker
				this.containersByMarker[marker] = container;
			}
			if(marker.patternId == 8)	{
				m_08 = true;
				var _ch3nh2:DisplayObject3D = new DisplayObject3D();
				var _ch3nh2a:DisplayObject3D = new DisplayObject3D(); //c group
				var _ch3nh2b:DisplayObject3D = new DisplayObject3D(); //n group
				var _ch3nh2b_lonePair01:DisplayObject3D = new DisplayObject3D();
				_ch3nh2b_lonePair01.z = -47;
	            _ch3nh2b_lonePair01.y = 17;
	            _ch3nh2b_lonePair01.rotationZ = 90;
	            _ch3nh2b_lonePair01.rotationY = -20;
				_ch3nh2a.y = -25; //c group
				_ch3nh2b.y = 25; //n group
				_ch3nh2.z = 50;
				ch3nh2_carbon01.visible = true;
	            ch3nh2_nitrogen01.visible = true;
	            ch3nh2_hydrogen01.visible = true;
	            ch3nh2_hydrogen02.visible = true;
	            ch3nh2_hydrogen03.visible = true;
	            ch3nh2_hydrogen04.visible = true;
	            ch3nh2_hydrogen05.visible = true;
	            ch3nh2_electron01a.visible = true;
	            ch3nh2_electron01b.visible = true;
	            ch3nh2_bond01.visible = true;
	            ch3nh2_bond02.visible = true;
	            ch3nh2_bond03.visible = true;
	            ch3nh2_bond04.visible = true;
	            ch3nh2_bond05.visible = true;
	            ch3nh2_bond06.visible = true;
	            ch3nh2_bond07.visible = true;
	            _ch3nh2b_lonePair01.addChild(ch3nh2_electron01a);
	            _ch3nh2b_lonePair01.addChild(ch3nh2_electron01b);
	            _ch3nh2a.addChild(ch3nh2_carbon01);
	            _ch3nh2a.addChild(ch3nh2_hydrogen01);
	            _ch3nh2a.addChild(ch3nh2_hydrogen02);
	            _ch3nh2a.addChild(ch3nh2_hydrogen03);
	            _ch3nh2a.addChild(ch3nh2_bond02);
	            _ch3nh2a.addChild(ch3nh2_bond03);
	            _ch3nh2a.addChild(ch3nh2_bond04);
	            _ch3nh2b.addChild(ch3nh2_nitrogen01);
	            _ch3nh2b.addChild(ch3nh2_hydrogen04);
	            _ch3nh2b.addChild(ch3nh2_hydrogen05);
	            _ch3nh2b.addChild(_ch3nh2b_lonePair01);
	            _ch3nh2b.addChild(ch3nh2_bond05);
	            _ch3nh2b.addChild(ch3nh2_bond06);
	            _ch3nh2b.addChild(ch3nh2_bond07);
	            _ch3nh2.addChild(_ch3nh2a);
	            _ch3nh2.addChild(_ch3nh2b);
	            _ch3nh2.addChild(ch3nh2_bond01);
	            
				container.addChild(_ch3nh2);
				this.scene3D.addChild(container);
				
				// associate container with corresponding marker
				this.containersByMarker[marker] = container;
			}
			if(marker.patternId == 9)	{
				m_09 = true;
				var _of2:DisplayObject3D = new DisplayObject3D();
				var _of2_lonePair01:DisplayObject3D = new DisplayObject3D();
				var _of2_lonePair02:DisplayObject3D = new DisplayObject3D();
				_of2.z = 50;
				_of2.rotationZ = 90;
				_of2_lonePair01.x = -4.12;
				_of2_lonePair01.y = 0;
          		_of2_lonePair01.z = 23.4;
          		_of2_lonePair01.rotationX = 80;
	            _of2_lonePair01.rotationY = 0;
	            _of2_lonePair01.rotationZ = 90;
	            _of2_lonePair02.x = 20.6;
	            _of2_lonePair02.y = 0;
	            _of2_lonePair02.z = -11.9;
	            _of2_lonePair02.rotationX = 30;
	            _of2_lonePair02.rotationY = 0;
	            _of2_lonePair02.rotationZ = 90;
				
				of2_oxygen01.visible = true;
				of2_fluoride01.visible = true;
				of2_fluoride02.visible = true;
				of2_bond01.visible = true;
				of2_bond02.visible = true;
				of2_bond03.visible = true;
				of2_bond04.visible = true;
				of2_electron01a.visible = true;
				of2_electron01b.visible = true;
				of2_electron02a.visible = true;
				of2_electron02b.visible = true;
				// remove these completley if DAE works out
				//of2_line01.visible = true;
				//of2_line02.visible = true;
				//of2_arrowHead01a.visible = true;
				//of2_arrowHead01b.visible = true;
				//of2_arrowHead02a.visible = true;
				//of2_arrowHead02b.visible = true;
				of2_arrowDAE01.visible = true;
				of2_arrowDAE02.visible = true;
				_of2_lonePair01.addChild(of2_electron01a);
				_of2_lonePair01.addChild(of2_electron01b);
				_of2_lonePair02.addChild(of2_electron02a);
				_of2_lonePair02.addChild(of2_electron02b);
				_of2.addChild(_of2_lonePair01);
				_of2.addChild(_of2_lonePair02);
				_of2.addChild(of2_oxygen01);
				_of2.addChild(of2_fluoride01);
				_of2.addChild(of2_fluoride02);
				_of2.addChild(of2_bond01);
				_of2.addChild(of2_bond02);
				_of2.addChild(of2_bond03);
				_of2.addChild(of2_bond04);
				_of2.addChild(of2_arrowDAE01);
				_of2.addChild(of2_arrowDAE02);	
				container.addChild(_of2);
				this.scene3D.addChild(container);
				
				// associate container with corresponding marker
				this.containersByMarker[marker] = container;
			}
			if(marker.patternId == 10)	{
				m_10 = true;
				var _sp3sp2sp:DisplayObject3D = new DisplayObject3D();
				var _sp:DisplayObject3D = new DisplayObject3D();
				var _sp2:DisplayObject3D = new DisplayObject3D();
				var _sp3:DisplayObject3D = new DisplayObject3D();
				var _sp2_electron02:DisplayObject3D = new DisplayObject3D();
				var _sp2_electron03:DisplayObject3D = new DisplayObject3D();
				var _sp3_electron02:DisplayObject3D = new DisplayObject3D();
				var _sp3_electron03:DisplayObject3D = new DisplayObject3D();
				var _sp3_electron04:DisplayObject3D = new DisplayObject3D();
				_sp3sp2sp.rotationZ = 90;
				_sp.x = -75;
				_sp.z = 50;
				_sp2.z = 50;
				_sp3.x = 75;
				_sp3.z = 50;
				_sp2_electron02.x = -12.5;
				_sp2_electron02.y = -21.7;
				_sp2_electron02.rotationX = 0;
				_sp2_electron02.rotationY = 0;
				_sp2_electron02.rotationZ = 150;
				_sp2_electron03.x = -12.5;
				_sp2_electron03.y = 21.7;
				_sp2_electron03.rotationX = 0;
				_sp2_electron03.rotationY = 0;
				_sp2_electron03.rotationZ = 210;
				_sp3_electron02.z = -5.5;
	            _sp3_electron02.x = 23.5;
	            _sp3_electron02.rotationZ = 90;
	            _sp3_electron02.rotationX = 20;
	            _sp3_electron03.z = -5.5;
	            _sp3_electron03.x = -12.5;
	            _sp3_electron03.y = -21.5;
	            _sp3_electron03.rotationZ = -30;
	            _sp3_electron03.rotationX = 20;
	            _sp3_electron04.z = -5.5;
	            _sp3_electron04.x = -12.5;
	            _sp3_electron04.y = 21.5;
	            _sp3_electron04.rotationZ = -150;
	            _sp3_electron04.rotationX = 20;
				
				sp_carbon01.visible = true;
				sp_bond01.visible = true;
				sp_bond02.visible = true;
				sp_electron01.visible = true;
				sp_electron02.visible = true;
				sp_lobe01upper.visible = true;
				sp_lobe01lower.visible = true;
				sp_lobe02upper.visible = true;
				sp_lobe02lower.visible = true;
				sp2_carbon01.visible = true;
				sp2_bond01.visible = true;
				sp2_bond02.visible = true;
				sp2_bond03.visible = true;
				sp2_electron01.visible = true;
				sp2_electron02.visible = true;
				sp2_electron03.visible = true;
				sp2_lobe01upper.visible = true;
				sp2_lobe01lower.visible = true;
				sp3_carbon01.visible = true;
				sp3_bond01.visible = true;
				sp3_bond02.visible = true;
				sp3_bond03.visible = true;
				sp3_bond04.visible = true;
				sp3_electron01.visible = true;
				sp3_electron02.visible = true;
				sp3_electron03.visible = true;
				sp3_electron04.visible = true;
				_sp2_electron02.addChild(sp2_electron02);
				_sp2_electron03.addChild(sp2_electron03);
				_sp3_electron02.addChild(sp3_electron02);
				_sp3_electron03.addChild(sp3_electron03);
				_sp3_electron04.addChild(sp3_electron04);
				_sp.addChild(sp_carbon01);
				_sp.addChild(sp_bond01);
				_sp.addChild(sp_bond02);
				_sp.addChild(sp_electron01);
				_sp.addChild(sp_electron02);
				_sp.addChild(sp_lobe01upper);
				_sp.addChild(sp_lobe01lower);
				_sp.addChild(sp_lobe02upper);
				_sp.addChild(sp_lobe02lower);
				_sp2.addChild(sp2_carbon01);
				_sp2.addChild(sp2_bond01);
				_sp2.addChild(sp2_bond02);
				_sp2.addChild(sp2_bond03);
				_sp2.addChild(sp2_electron01);
				_sp2.addChild(sp2_lobe01upper);
				_sp2.addChild(sp2_lobe01lower);
				_sp2.addChild(_sp2_electron02);
				_sp2.addChild(_sp2_electron03);
				_sp3.addChild(sp3_carbon01);
				_sp3.addChild(sp3_bond01);
				_sp3.addChild(sp3_bond02);
				_sp3.addChild(sp3_bond03);
				_sp3.addChild(sp3_bond04);
				_sp3.addChild(sp3_electron01);
				_sp3.addChild(_sp3_electron02);
				_sp3.addChild(_sp3_electron03);
				_sp3.addChild(_sp3_electron04);
				_sp3sp2sp.addChild(_sp);
				_sp3sp2sp.addChild(_sp2);
				_sp3sp2sp.addChild(_sp3);
				container.addChild(_sp3sp2sp);
				
				this.scene3D.addChild(container);
				
				// associate container with corresponding marker
				this.containersByMarker[marker] = container;
			}
		}
		
		public function removeMarker (marker:FLARMarker) :void {
			// find and remove marker
			var markerList:Vector.<FLARMarker> = this.markersByPatternId[marker.patternId];
			var markerIndex:uint = markerList.indexOf(marker);
			if (markerIndex != -1) {
				markerList.splice(markerIndex, 1);
			}
			
			// find and remove corresponding container
			var container:DisplayObject3D = this.containersByMarker[marker];
			if (container) {
				this.scene3D.removeChild(container);
			}
			delete this.containersByMarker[marker]
			
			if(marker.patternId == 0)	{
				m_00 = false;
				ch4_carbon01.visible = false;
	            ch4_hydrogen01.visible = false;
	            ch4_hydrogen02.visible = false;
	            ch4_hydrogen03.visible = false;
	            ch4_hydrogen04.visible = false;
	            ch4_bond01.visible = false;
	            ch4_bond02.visible = false;
	            ch4_bond03.visible = false;
	            ch4_bond04.visible = false;
	            //ch4_shadow.visible = false;
	  		}
	        if(marker.patternId == 1)	{
	        	m_01 = false;
	            nh3_nitrogen01.visible = false;
	            nh3_hydrogen01.visible = false;
	            nh3_hydrogen02.visible = false;
	            nh3_hydrogen03.visible = false;
	            nh3_bond01.visible = false;
	            nh3_bond02.visible = false;
	            nh3_bond03.visible = false;
	            nh3_bond04.visible = false;
	            nh3_electron01a.visible = false;
	            nh3_electron01b.visible = false;
	  		}
	  		if(marker.patternId == 2)	{
	  			m_02 = false;
	  			c3h6_carbon01.visible = false;
				c3h6_carbon02.visible = false;
				c3h6_carbon03.visible = false;
				c3h6_hydrogen01.visible = false;
				c3h6_hydrogen02.visible = false;
				c3h6_hydrogen03.visible = false;
				c3h6_hydrogen04.visible = false;
				c3h6_hydrogen05.visible = false;
				c3h6_hydrogen06.visible = false;
				c3h6_lobe01upper.visible = false;
				c3h6_lobe01lower.visible = false;
				c3h6_lobe02upper.visible = false;
				c3h6_lobe02lower.visible = false;
				c3h6_bond01.visible = false;
				c3h6_bond02.visible = false;
				c3h6_bond03.visible = false;
				c3h6_bond04.visible = false;
				c3h6_bond05.visible = false;
				c3h6_bond06.visible = false;
				c3h6_bond07.visible = false;
				c3h6_bond08.visible = false;
				c3h6_lobeConnect01upperA.visible = false;
				c3h6_lobeConnect01lowerA.visible = false;
				c3h6_lobeConnect01upperB.visible = false;
				c3h6_lobeConnect01lowerB.visible = false;
				c3h6_lobeConnect01upperC.visible = false;
				c3h6_lobeConnect01lowerC.visible = false;
			}
			if(marker.patternId == 3)	{
				m_03 = false;
				c2h2_carbon01.visible = false;
	            c2h2_carbon02.visible = false;
	            c2h2_hydrogen01.visible = false;
	            c2h2_hydrogen02.visible = false;
	            c2h2_bond01.visible = false;
	            c2h2_bond02.visible = false;
	            c2h2_bond03.visible = false;
	            c2h2_lobe01upper.visible = false;
	            c2h2_lobe01lower.visible = false;
	            c2h2_lobe02upper.visible = false;
	            c2h2_lobe02lower.visible = false;
	            c2h2_lobe03upper.visible = false;
	            c2h2_lobe03lower.visible = false;
	            c2h2_lobe04upper.visible = false;
	            c2h2_lobe04lower.visible = false;
	            c2h2_lobeConnect01upperA.visible = false;
	            c2h2_lobeConnect01upperB.visible = false;
	            c2h2_lobeConnect01upperC.visible = false;
	            c2h2_lobeConnect01lowerA.visible = false;
	            c2h2_lobeConnect01lowerB.visible = false;
	            c2h2_lobeConnect01lowerC.visible = false;
	            c2h2_lobeConnect02upperA.visible = false;
	            c2h2_lobeConnect02upperB.visible = false;
	            c2h2_lobeConnect02upperC.visible = false;
	            c2h2_lobeConnect02lowerA.visible = false;
	            c2h2_lobeConnect02lowerB.visible = false;
	            c2h2_lobeConnect02lowerC.visible = false;
			}
			if(marker.patternId == 4)	{
				m_04 = false;
				c2h6_carbon01.visible = false;
				c2h6_carbon02.visible = false;
				c2h6_hydrogen01.visible = false;
				c2h6_hydrogen02.visible = false;
				c2h6_hydrogen03.visible = false;
				c2h6_hydrogen04.visible = false;
				c2h6_hydrogen05.visible = false;
				c2h6_hydrogen06.visible = false;
				c2h6_bond01.visible = false;
				c2h6_bond02.visible = false;
				c2h6_bond03.visible = false;
				c2h6_bond04.visible = false;
				c2h6_bond05.visible = false;
				c2h6_bond06.visible = false;
				c2h6_bond07.visible = false;
			}
			if(marker.patternId == 5)	{
				m_05 = false;
				ch3conh2_carbon01.visible = false;
	            ch3conh2_carbon02.visible = false;
	            ch3conh2_oxygen01.visible = false;
	            ch3conh2_hydrogen01.visible = false;
	            ch3conh2_hydrogen02.visible = false;
	            ch3conh2_hydrogen03.visible = false;
	            ch3conh2_hydrogen04.visible = false;
	            ch3conh2_hydrogen05.visible = false;
	            ch3conh2_nitrogen01.visible = false;
	            ch3conh2_electron01a.visible = false;
	            ch3conh2_electron01b.visible = false;
	            ch3conh2_electron02a.visible = false;
	            ch3conh2_electron02b.visible = false;
	            ch3conh2_electron03a.visible = false;
	            ch3conh2_electron03b.visible = false;
	            ch3conh2_bond01.visible = false;
	            ch3conh2_bond02.visible = false;
	            ch3conh2_bond03.visible = false;
	            ch3conh2_bond04.visible = false;
	            ch3conh2_bond05.visible = false;
	            ch3conh2_bond06.visible = false;
	            ch3conh2_bond07.visible = false;
	            ch3conh2_bond08.visible = false;
	            ch3conh2_bond09.visible = false;
	            ch3conh2_bond10.visible = false;
	            ch3conh2_bond11.visible = false;
	            ch3conh2_lobe01upper.visible = false;
	            ch3conh2_lobe01lower.visible = false;
	            ch3conh2_lobe02upper.visible = false;
	            ch3conh2_lobe02lower.visible = false;
	            ch3conh2_lobeConnect01upperA.visible = false;
	            ch3conh2_lobeConnect01upperB.visible = false;
	            ch3conh2_lobeConnect01upperC.visible = false;
	            ch3conh2_lobeConnect01lowerA.visible = false;
	            ch3conh2_lobeConnect01lowerB.visible = false;
	            ch3conh2_lobeConnect01lowerC.visible = false;
			}
			if(marker.patternId == 6)	{
				m_06 = false;
				co2_carbon01.visible = false;
				co2_oxygen01.visible = false;
				co2_oxygen02.visible = false;
				co2_electron01a.visible = false;
				co2_electron01b.visible = false;
				co2_electron02a.visible = false;
				co2_electron02b.visible = false;
				co2_electron03a.visible = false;
				co2_electron03b.visible = false;
				co2_electron04a.visible = false;
				co2_electron04b.visible = false;
				co2_bond01.visible = false;
				co2_bond02.visible = false;
				co2_bond03.visible = false;
				co2_bond04.visible = false;
				co2_bond05.visible = false;
				co2_bond06.visible = false;
				co2_lobe01upper.visible = false;
				co2_lobe01lower.visible = false;
				co2_lobe02upper.visible = false;
				co2_lobe02lower.visible = false;
				co2_lobe03upper.visible = false;
				co2_lobe03lower.visible = false;
				co2_lobe04upper.visible = false;
				co2_lobe04lower.visible = false;
				co2_lobeConnect01upperA.visible = false;
				co2_lobeConnect01lowerA.visible = false;
				co2_lobeConnect01upperB.visible = false;
				co2_lobeConnect01lowerB.visible = false;
				co2_lobeConnect01upperC.visible = false;
				co2_lobeConnect01lowerC.visible = false;
				co2_lobeConnect02upperA.visible = false;
				co2_lobeConnect02lowerA.visible = false;
				co2_lobeConnect02upperB.visible = false;
				co2_lobeConnect02lowerB.visible = false;
				co2_lobeConnect02upperC.visible = false;
				co2_lobeConnect02lowerC.visible = false;
			}
			if(marker.patternId == 7)	{
				m_07 = false;
				c2h4_carbon01.visible = false;
	            c2h4_carbon02.visible = false;
	            c2h4_hydrogen01.visible = false;
	            c2h4_hydrogen02.visible = false;
	            c2h4_hydrogen03.visible = false;
	            c2h4_hydrogen04.visible = false;
	            c2h4_bond01.visible = false;
	            c2h4_bond02.visible = false;
	            c2h4_bond03.visible = false;
	            c2h4_bond04.visible = false;
	            c2h4_bond05.visible = false;
	            c2h4_lobe01upper.visible = false;
	            c2h4_lobe01lower.visible = false;
	            c2h4_lobe02upper.visible = false;
	            c2h4_lobe02lower.visible = false;
	            c2h4_lobeConnect01upperA.visible = false;
	            c2h4_lobeConnect01lowerA.visible = false;
	            c2h4_lobeConnect01upperB.visible = false;
	            c2h4_lobeConnect01lowerB.visible = false;
	            c2h4_lobeConnect01upperC.visible = false;
	            c2h4_lobeConnect01lowerC.visible = false;
			}
			if(marker.patternId == 8)	{
				m_08 = false;
				ch3nh2_carbon01.visible = false;
	            ch3nh2_nitrogen01.visible = false;
	            ch3nh2_hydrogen01.visible = false;
	            ch3nh2_hydrogen02.visible = false;
	            ch3nh2_hydrogen03.visible = false;
	            ch3nh2_hydrogen04.visible = false;
	            ch3nh2_hydrogen05.visible = false;
	            ch3nh2_electron01a.visible = false;
	            ch3nh2_electron01b.visible = false;
	            ch3nh2_bond01.visible = false;
	            ch3nh2_bond02.visible = false;
	            ch3nh2_bond03.visible = false;
	            ch3nh2_bond04.visible = false;
	            ch3nh2_bond05.visible = false;
	            ch3nh2_bond06.visible = false;
	            ch3nh2_bond07.visible = false;
			}
			if(marker.patternId == 9)	{
				m_09 = false;
				of2_oxygen01.visible = false;
				of2_fluoride01.visible = false;
				of2_fluoride02.visible = false;
				of2_bond01.visible = false;
				of2_bond02.visible = false;
				of2_bond03.visible = false;
				of2_bond04.visible = false;
				of2_electron01a.visible = false;
				of2_electron01b.visible = false;
				of2_electron02a.visible = false;
				of2_electron02b.visible = false;
				of2_arrowDAE01.visible = false;
				of2_arrowDAE02.visible = false;
			}
			if(marker.patternId == 10)	{
				m_10 = false;
				sp_carbon01.visible = false;
				sp_bond01.visible = false;
				sp_bond02.visible = false;
				sp_electron01.visible = false;
				sp_electron02.visible = false;
				sp_lobe01upper.visible = false;
				sp_lobe01lower.visible = false;
				sp_lobe02upper.visible = false;
				sp_lobe02lower.visible = false;
				sp2_carbon01.visible = false;
				sp2_bond01.visible = false;
				sp2_bond02.visible = false;
				sp2_bond03.visible = false;
				sp2_electron01.visible = false;
				sp2_electron02.visible = false;
				sp2_electron03.visible = false;
				sp2_lobe01upper.visible = false;
				sp2_lobe01lower.visible = false;
				sp3_carbon01.visible = false;
				sp3_bond01.visible = false;
				sp3_bond02.visible = false;
				sp3_bond03.visible = false;
				sp3_bond04.visible = false;
				sp3_electron01.visible = false;
				sp3_electron02.visible = false;
				sp3_electron03.visible = false;
				sp3_electron04.visible = false;
			}
		}
		
		private function init (numPatterns:uint) :void {
			// set up lists (Vectors) of FLARMarkers, arranged by patternId
			this.markersByPatternId = new Vector.<Vector.<FLARMarker>>(numPatterns, true);
			while (numPatterns--) {
				this.markersByPatternId[numPatterns] = new Vector.<FLARMarker>();
			}
			
			// prepare hashtable for associating Cube containers with FLARMarkers
			this.containersByMarker = new Dictionary(true);
		}
		
		private function initPapervisionEnvironment (cameraParams:FLARParam, viewportWidth:Number, viewportHeight:Number) :void {
			this.scene3D = new Scene3D();
			this.camera3D = new FLARCamera3D();
			this.camera3D.setParam(cameraParams);
			
			this.viewport3D = new Viewport3D(viewportWidth, viewportHeight);
			this.addChild(this.viewport3D);
			
			this.renderEngine = new LazyRenderEngine(this.scene3D, this.camera3D, this.viewport3D);
			
			this.pointLight3D = new PointLight3D();
			//this.pointLight3D.x = 1000;
			//this.pointLight3D.y = 1000;
			//this.pointLight3D.z = -1000;
			
			this.addEventListener(Event.ENTER_FRAME, this.onEnterFrame);
		}
		
		private function onEnterFrame (evt:Event) :void {
			this.updateMolecules();
			this.renderEngine.render();
		}
		
		private function updateMolecules () :void {
			if(m_00 == true && m_01 == false && m_02 == false && m_03 == false && m_04 == false && m_05 == false && m_06 == false && m_07 == false && m_08 == false && m_09 == false && m_10 ==false)	{
				p_00.visible = true;
			}
			else	{
				p_00.visible = false;
			}
			if(m_00 == false && m_01 == true && m_02 == false && m_03 == false && m_04 == false && m_05 == false && m_06 == false && m_07 == false && m_08 == false && m_09 == false && m_10 ==false)	{
				p_01.visible = true;
			}
			else	{
				p_01.visible = false;
			}
			if(m_00 == false && m_01 == false && m_02 == true && m_03 == false && m_04 == false && m_05 == false && m_06 == false && m_07 == false && m_08 == false && m_09 == false && m_10 ==false)	{
				p_02.visible = true;
			}
			else	{
				p_02.visible = false;
			}
			if(m_00 == false && m_01 == false && m_02 == false && m_03 == true && m_04 == false && m_05 == false && m_06 == false && m_07 == false && m_08 == false && m_09 == false && m_10 ==false)	{
				p_03.visible = true;
			}
			else	{
				p_03.visible = false;
			}
			if(m_00 == false && m_01 == false && m_02 == false && m_03 == false && m_04 == true && m_05 == false && m_06 == false && m_07 == false && m_08 == false && m_09 == false && m_10 ==false)	{
				p_04.visible = true;
			}
			else	{
				p_04.visible = false;
			}
			if(m_00 == false && m_01 == false && m_02 == false && m_03 == false && m_04 == false && m_05 == true && m_06 == false && m_07 == false && m_08 == false && m_09 == false && m_10 ==false)	{
				p_05.visible = true;
			}
			else	{
				p_05.visible = false;
			}
			if(m_00 == false && m_01 == false && m_02 == false && m_03 == false && m_04 == false && m_05 == false && m_06 == true && m_07 == false && m_08 == false && m_09 == false && m_10 ==false)	{
				p_06.visible = true;
			}
			else	{
				p_06.visible = false;
			}
			if(m_00 == false && m_01 == false && m_02 == false && m_03 == false && m_04 == false && m_05 == false && m_06 == false && m_07 == true && m_08 == false && m_09 == false && m_10 ==false)	{
				p_07.visible = true;
			}
			else	{
				p_07.visible = false;
			}
			if(m_00 == false && m_01 == false && m_02 == false && m_03 == false && m_04 == false && m_05 == false && m_06 == false && m_07 == false && m_08 == true && m_09 == false && m_10 ==false)	{
				p_08.visible = true;
			}
			else	{
				p_08.visible = false;
			}
			if(m_00 == false && m_01 == false && m_02 == false && m_03 == false && m_04 == false && m_05 == false && m_06 == false && m_07 == false && m_08 == false && m_09 == true && m_10 ==false)	{
				p_09.visible = true;
			}
			else	{
				p_09.visible = false;
			}
			if(m_00 == false && m_01 == false && m_02 == false && m_03 == false && m_04 == false && m_05 == false && m_06 == false && m_07 == false && m_08 == false && m_09 == false && m_10 ==true)	{
				p_10.visible = true;
			}
			else	{
				p_10.visible = false;
			}
			// update all containers according to the transformation matrix in their associated FLARMarkers
			var i:int = this.markersByPatternId.length;
			var markerList:Vector.<FLARMarker>;
			var marker:FLARMarker;
			var container:DisplayObject3D;
			var j:int;
			while (i--) {
				markerList = this.markersByPatternId[i];
				j = markerList.length;
				while (j--) {
					marker = markerList[j];
					container = this.containersByMarker[marker];
					container.transform = FLARPVGeomUtils.convertFLARMatrixToPVMatrix(marker.transformMatrix, this.bMirrorDisplay);
				}
			}
		}
	}
}